@@ -67,12 +67,12 @@ mm_multi_file_io_c::setFilePointer(int64 offset,
     : seek_end       == mode ? m_total_size  - offset
     :                          m_current_pos + offset;
 
-  if ((0 > new_pos) || (m_total_size < new_pos))
+  if ((0 > new_pos) || (static_cast<int64_t>(m_total_size) < new_pos))
     throw mm_io_seek_error_c();
 
   m_current_file = 0;
   foreach(const mm_multi_file_io_c::file_t &file, m_files) {
-    if ((file.m_global_start + file.m_size) < new_pos) {
+    if ((file.m_global_start + file.m_size) < static_cast<uint64_t>(new_pos)) {
       ++m_current_file;
       continue;
     }
@@ -181,14 +181,15 @@ struct path_sorter_t {
 };
 
 mm_multi_file_io_cptr
-mm_multi_file_io_c::open_multi(const std::string &display_file_name) {
+mm_multi_file_io_c::open_multi(const std::string &display_file_name,
+                               bool single_only) {
   bfs::path first_file_name(bfs::system_complete(bfs::path(display_file_name)));
   std::string base_name = bfs::basename(first_file_name);
   std::string extension = downcase(bfs::extension(first_file_name));
   boost::regex file_name_re("(.+?)(\\d+)", boost::regex::perl);
   boost::smatch matches;
 
-  if (!boost::regex_match(base_name, matches, file_name_re)) {
+  if (!boost::regex_match(base_name, matches, file_name_re) || single_only) {
     std::vector<bfs::path> file_names;
     file_names.push_back(first_file_name);
     return mm_multi_file_io_cptr(new mm_multi_file_io_c(file_names, display_file_name));
