@@ -282,7 +282,7 @@ _show_element(EbmlElement *l,
   // Dump unknown elements recursively.
   EbmlMaster *m = dynamic_cast<EbmlMaster *>(l);
   if (NULL != m) {
-    int i;
+    size_t i;
     for (i = 0; i < m->ListSize(); i++)
       show_unknown_element((*m)[i], level + 1);
   }
@@ -327,10 +327,50 @@ to_hex(const unsigned char *buf,
   return hex;
 }
 
+std::string
+create_codec_dependent_private_info(KaxCodecPrivate &c_priv,
+                                    char track_type,
+                                    const std::string &codec_id) {
+  if ((codec_id == MKV_V_MSCOMP) && ('v' == track_type) && (c_priv.GetSize() >= sizeof(alBITMAPINFOHEADER))) {
+    alBITMAPINFOHEADER *bih = reinterpret_cast<alBITMAPINFOHEADER *>(c_priv.GetBuffer());
+    unsigned char *fcc      = reinterpret_cast<unsigned char *>(&bih->bi_compression);
+    return (boost::format(Y(" (FourCC: %1%%2%%3%%4%, 0x%|5$08x|)"))
+            % fcc[0] % fcc[1] % fcc[2] % fcc[3] % get_uint32_le(&bih->bi_compression)).str();
+
+  } else if ((codec_id == MKV_A_ACM) && ('a' == track_type) && (c_priv.GetSize() >= sizeof(alWAVEFORMATEX))) {
+    alWAVEFORMATEX *wfe     = reinterpret_cast<alWAVEFORMATEX *>(c_priv.GetBuffer());
+    return (boost::format(Y(" (format tag: 0x%|1$04x|)")) % get_uint16_le(&wfe->w_format_tag)).str();
+
+  } else if ((codec_id == MKV_V_MPEG4_AVC) && ('v' == track_type) && (c_priv.GetSize() >= 4)) {
+    unsigned char *avcc      = c_priv.GetBuffer();
+    unsigned int profile_idc = avcc[1];
+    unsigned int level_idc   = avcc[3];
+
+    return (boost::format(Y(" (h.264 profile: %1% @L%2%.%3%)"))
+            % (  profile_idc ==  44 ? "CAVLC 4:4:4 Intra"
+               : profile_idc ==  66 ? "Baseline"
+               : profile_idc ==  77 ? "Main"
+               : profile_idc ==  83 ? "Scalable Baseline"
+               : profile_idc ==  86 ? "Scalable High"
+               : profile_idc ==  88 ? "Extended"
+               : profile_idc == 100 ? "High"
+               : profile_idc == 110 ? "High 10"
+               : profile_idc == 118 ? "Multiview High"
+               : profile_idc == 122 ? "High 4:2:2"
+               : profile_idc == 128 ? "Stereo High"
+               : profile_idc == 144 ? "High 4:4:4"
+               : profile_idc == 244 ? "High 4:4:4 Predictive"
+               :                      Y("Unknown"))
+            % (level_idc / 10) % (level_idc % 10)).str();
+  }
+
+  return "";
+}
+
 void
 parse_args(std::vector<std::string> args,
            std::string &file_name) {
-  int i;
+  size_t i;
 
   verbose = 0;
   file_name = "";
@@ -427,7 +467,7 @@ struct master_sorter_t {
 
 void
 sort_master(EbmlMaster &m) {
-  int i;
+  size_t i;
   std::vector<EbmlElement *> tmp;
   std::vector<master_sorter_t> sort_me;
 
@@ -459,8 +499,8 @@ read_master(EbmlMaster *m,
 
 std::string
 format_binary(EbmlBinary &bin,
-              int max_len = 10) {
-  int len            = std::min(max_len, (int)bin.GetSize());
+              size_t max_len = 10) {
+  size_t len         = std::min(max_len, static_cast<size_t>(bin.GetSize()));
   const binary *b    = bin.GetBuffer();
   std::string result = (BF_FORMAT_BINARY_1 % bin.GetSize() % to_hex(b, len)).str();
 
@@ -514,12 +554,10 @@ format_binary(EbmlBinary &bin,
 
 void
 def_handle(chaptertranslate) {
-  EbmlMaster *m2;
-  int i2;
-
   show_element(l2, 2, Y("Chapter Translate"));
 
-  m2 = static_cast<EbmlMaster *>(l2);
+  size_t i2;
+  EbmlMaster *m2 = static_cast<EbmlMaster *>(l2);
   for (i2 = 0; i2 < m2->ListSize(); i2++) {
     l3 = (*m2)[i2];
 
@@ -548,7 +586,7 @@ def_handle(info) {
   EbmlElement *element_found = NULL;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
-  int i1;
+  size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
     l2 = (*m1)[i1];
 
@@ -630,12 +668,10 @@ def_handle(info) {
 void
 def_handle2(audio_track,
             std::vector<std::string> &summary) {
-  EbmlMaster *m3;
-  int i3;
-
   show_element(l3, 3, "Audio track");
 
-  m3 = static_cast<EbmlMaster *>(l3);
+  size_t i3;
+  EbmlMaster *m3 = static_cast<EbmlMaster *>(l3);
   for (i3 = 0; i3 < m3->ListSize(); i3++) {
     l4 = (*m3)[i3];
 
@@ -677,7 +713,7 @@ def_handle2(video_track,
   show_element(l3, 3, Y("Video track"));
 
   EbmlMaster *m3 = static_cast<EbmlMaster *>(l3);
-  int i3;
+  size_t i3;
   for (i3 = 0; i3 < m3->ListSize(); i3++) {
     l4 = (*m3)[i3];
 
@@ -780,7 +816,7 @@ def_handle(content_encodings) {
   show_element(l3, 3, Y("Content encodings"));
 
   EbmlMaster *m3 = static_cast<EbmlMaster *>(l3);
-  int i3;
+  size_t i3;
   for (i3 = 0; i3 < m3->ListSize(); i3++) {
     l4 = (*m3)[i3];
 
@@ -788,7 +824,7 @@ def_handle(content_encodings) {
       show_element(l4, 4, Y("Content encoding"));
 
       EbmlMaster *m4 = static_cast<EbmlMaster *>(l4);
-      int i4;
+      size_t i4;
       for (i4 = 0; i4 < m4->ListSize(); i4++) {
         l5 = (*m4)[i4];
 
@@ -823,7 +859,7 @@ def_handle(content_encodings) {
           show_element(l5, 5, Y("Content compression"));
 
           EbmlMaster *m5 = static_cast<EbmlMaster *>(l5);
-          int i5;
+          size_t i5;
           for (i5 = 0; i5 < m5->ListSize(); i5++) {
             l6 = (*m5)[i5];
 
@@ -850,7 +886,7 @@ def_handle(content_encodings) {
           show_element(l5, 5, Y("Content encryption"));
 
           EbmlMaster *m5 = static_cast<EbmlMaster *>(l5);
-          int i5;
+          size_t i5;
           for (i5 = 0; i5 < m5->ListSize(); i5++) {
             l6 = (*m5)[i5];
 
@@ -925,7 +961,7 @@ def_handle(tracks) {
   EbmlElement *element_found = NULL;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
-  int i1;
+  size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
     l2 = (*m1)[i1];
 
@@ -940,7 +976,7 @@ def_handle(tracks) {
       EbmlMaster *m2           = static_cast<EbmlMaster *>(l2);
       std::string kax_codec_id;
       std::string fourcc_buffer;
-      int i2;
+      size_t i2;
 
       for (i2 = 0; i2 < m2->ListSize(); i2++) {
         l3 = (*m2)[i2];
@@ -1014,17 +1050,8 @@ def_handle(tracks) {
             ms_compat = true;
 
         } else if (is_id(l3, KaxCodecPrivate)) {
-          fourcc_buffer = "";
           KaxCodecPrivate &c_priv = *static_cast<KaxCodecPrivate *>(l3);
-          if (ms_compat && ('v' == kax_track_type) && (c_priv.GetSize() >= sizeof(alBITMAPINFOHEADER))) {
-            alBITMAPINFOHEADER *bih = (alBITMAPINFOHEADER *)c_priv.GetBuffer();
-            unsigned char *fcc      = (unsigned char *)&bih->bi_compression;
-            fourcc_buffer           = (boost::format(Y(" (FourCC: %1%%2%%3%%4%, 0x%|5$08x|)"))
-                                       % fcc[0] % fcc[1] % fcc[2] % fcc[3] % get_uint32_le(&bih->bi_compression)).str();
-          } else if (ms_compat && ('a' == kax_track_type) && (c_priv.GetSize() >= sizeof(alWAVEFORMATEX))) {
-            alWAVEFORMATEX *wfe     = (alWAVEFORMATEX *)c_priv.GetBuffer();
-            fourcc_buffer           = (boost::format(Y(" (format tag: 0x%|1$04x|)")) % get_uint16_le(&wfe->w_format_tag)).str();
-          }
+          fourcc_buffer = create_codec_dependent_private_info(c_priv, kax_track_type, kax_codec_id);
 
           if (s_calc_checksums && !s_show_summary)
             fourcc_buffer += (boost::format(Y(" (adler: 0x%|1$08x|)")) % calc_adler32(c_priv.GetBuffer(), c_priv.GetSize())).str();
@@ -1147,7 +1174,7 @@ def_handle(seek_head) {
   EbmlElement *element_found = NULL;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
-  int i1;
+  size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
     l2 = (*m1)[i1];
 
@@ -1155,7 +1182,7 @@ def_handle(seek_head) {
       show_element(l2, 2, Y("Seek entry"));
 
       EbmlMaster *m2 = static_cast<EbmlMaster *>(l2);
-      int i2;
+      size_t i2;
       for (i2 = 0; i2 < m2->ListSize(); i2++) {
         l3 = (*m2)[i2];
 
@@ -1207,7 +1234,7 @@ def_handle(cues) {
   EbmlElement *element_found = NULL;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
-  int i1;
+  size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
     l2 = (*m1)[i1];
 
@@ -1215,7 +1242,7 @@ def_handle(cues) {
       show_element(l2, 2, Y("Cue point"));
 
       EbmlMaster *m2 = static_cast<EbmlMaster *>(l2);
-      int i2;
+      size_t i2;
       for (i2 = 0; i2 < m2->ListSize(); i2++) {
         l3 = (*m2)[i2];
 
@@ -1227,7 +1254,7 @@ def_handle(cues) {
           show_element(l3, 3, Y("Cue track positions"));
 
           EbmlMaster *m3 = static_cast<EbmlMaster *>(l3);
-          int i3;
+          size_t i3;
           for (i3 = 0; i3 < m3->ListSize(); i3++) {
             l4 = (*m3)[i3];
 
@@ -1252,7 +1279,7 @@ def_handle(cues) {
               show_element(l4, 4, Y("Cue reference"));
 
               EbmlMaster *m4 = static_cast<EbmlMaster *>(l4);
-              int i4;
+              size_t i4;
               for (i4 = 0; i4 < m4->ListSize(); i4++) {
                 l5 = (*m4)[i4];
 
@@ -1305,7 +1332,7 @@ def_handle(attachments) {
   EbmlElement *element_found = NULL;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
-  int i1;
+  size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
     l2 = (*m1)[i1];
 
@@ -1313,7 +1340,7 @@ def_handle(attachments) {
       show_element(l2, 2, Y("Attached"));
 
       EbmlMaster *m2 = static_cast<EbmlMaster *>(l2);
-      int i2;
+      size_t i2;
       for (i2 = 0; i2 < m2->ListSize(); i2++) {
         l3 = (*m2)[i2];
 
@@ -1356,7 +1383,7 @@ def_handle2(silent_track,
   show_element(l2, 2, "Silent Tracks");
   EbmlMaster *m2 = static_cast<EbmlMaster *>(l2);
 
-  int i2;
+  size_t i2;
   for (i2 = 0; i2 < m2->ListSize(); i2++) {
     l3 = (*m2)[i2];
 
@@ -1389,7 +1416,7 @@ def_handle2(block_group,
 
   EbmlMaster *m2      = static_cast<EbmlMaster *>(l2);
 
-  int i2;
+  size_t i2;
   for (i2 = 0; i2 < m2->ListSize(); i2++) {
     l3 = (*m2)[i2];
 
@@ -1469,7 +1496,7 @@ def_handle2(block_group,
       show_element(l3, 3, Y("Additions"));
 
       EbmlMaster *m3 = static_cast<EbmlMaster *>(l3);
-      int i3;
+      size_t i3;
       for (i3 = 0; i3 < m3->ListSize(); i3++) {
         l4 = (*m3)[i3];
 
@@ -1477,7 +1504,7 @@ def_handle2(block_group,
           show_element(l4, 4, Y("More"));
 
           EbmlMaster *m4 = static_cast<EbmlMaster *>(l4);
-          int i4;
+          size_t i4;
           for (i4 = 0; i4 < m4->ListSize(); i4++) {
             l5 = (*m4)[i4];
 
@@ -1503,7 +1530,7 @@ def_handle2(block_group,
       show_element(l3, 3, Y("Slices"));
 
       EbmlMaster *m3 = static_cast<EbmlMaster *>(l3);
-      int i3;
+      size_t i3;
       for (i3 = 0; i3 < m3->ListSize(); i3++) {
         l4 = (*m3)[i3];
 
@@ -1511,7 +1538,7 @@ def_handle2(block_group,
           show_element(l4, 4, Y("Time slice"));
 
           EbmlMaster *m4 = static_cast<EbmlMaster *>(l4);
-          int i4;
+          size_t i4;
           for (i4 = 0; i4 < m4->ListSize(); i4++) {
             l5 = (*m4)[i4];
 
@@ -1552,7 +1579,7 @@ def_handle2(block_group,
 
   if (s_show_summary) {
     std::string position;
-    int fidx;
+    size_t fidx;
 
     for (fidx = 0; fidx < frame_sizes.size(); fidx++) {
       if (1 <= verbose) {
@@ -1640,7 +1667,7 @@ def_handle2(simple_block,
 
   if (s_show_summary) {
     std::string position;
-    int fidx;
+    size_t fidx;
 
     for (fidx = 0; fidx < frame_sizes.size(); fidx++) {
       if (1 <= verbose) {
@@ -1683,7 +1710,7 @@ def_handle3(cluster,
   KaxClusterTimecode *cluster_tc = FINDFIRST(m1, KaxClusterTimecode);
   cluster->InitTimecode(NULL == cluster_tc ? 0 : uint64(*cluster_tc), s_tc_scale);
 
-  int i1;
+  size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++) {
     l2 = (*m1)[i1];
 
@@ -1746,7 +1773,7 @@ handle_elements_rec(EbmlStream *es,
       m = dynamic_cast<EbmlMaster *>(e);
       assert(m != NULL);
 
-      int i;
+      size_t i;
       for (i = 0; m->ListSize() > i; ++i)
         handle_elements_rec(es, level + 1, elt_idx, (*m)[i], mapping);
       break;
@@ -1786,7 +1813,7 @@ def_handle(chapters) {
   EbmlElement *element_found = NULL;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
-  int i1;
+  size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
     handle_elements_rec(es, 2, 0, (*m1)[i1], chapter_elements);
 
@@ -1802,7 +1829,7 @@ def_handle(tags) {
   EbmlElement *element_found = NULL;
   read_master(m1, es, EBML_CONTEXT(l1), upper_lvl_el, element_found);
 
-  int i1;
+  size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
     handle_elements_rec(es, 2, 0, (*m1)[i1], tag_elements);
 
