@@ -59,7 +59,7 @@ avi_subs_demuxer_t::avi_subs_demuxer_t()
 
 int
 avi_reader_c::probe_file(mm_io_c *io,
-                         int64_t size) {
+                         uint64_t size) {
   unsigned char data[12];
 
   if (12 > size)
@@ -93,6 +93,7 @@ avi_reader_c::avi_reader_c(track_info_c &_ti)
   , m_avc_nal_size_size(-1)
   , m_bytes_to_process(0)
   , m_bytes_processed(0)
+  , m_video_track_ok(false)
 {
   int64_t size;
 
@@ -115,6 +116,7 @@ avi_reader_c::avi_reader_c(track_info_c &_ti)
   m_fps              = AVI_frame_rate(m_avi);
   m_max_video_frames = AVI_video_frames(m_avi);
 
+  verify_video_track();
   parse_subtitle_chunks();
 
   if (debugging_requested("avi_dump_video_index"))
@@ -130,6 +132,21 @@ avi_reader_c::~avi_reader_c() {
   mxverb(2, boost::format("avi_reader_c: Dropped video frames: %1%\n") % m_dropped_video_frames);
 }
 
+void
+avi_reader_c::verify_video_track() {
+  alBITMAPINFOHEADER *bih = m_avi->bitmap_info_header;
+  size_t size             = get_uint32_le(&bih->bi_size);
+
+  if (sizeof(alBITMAPINFOHEADER) > size)
+    return;
+
+  const char *codec = AVI_video_compressor(m_avi);
+  if ((0 == codec[0]) || (0 == AVI_video_width(m_avi)) || (0 == AVI_video_height(m_avi)))
+    return;
+
+  m_video_track_ok = true;
+}
+
 void
 avi_reader_c::parse_subtitle_chunks() {
   int i;
@@ -160,7 +177,7 @@ avi_reader_c::parse_subtitle_chunks() {
 
       io.skip(1);
 
-      while (!io.eof() && (io.getFilePointer() < chunk_size)) {
+      while (!io.eof() && (io.getFilePointer() < static_cast<size_t>(chunk_size))) {
         uint16_t id = io.read_uint16_le();
         int len     = io.read_uint32_le();
 
@@ -191,53 +208,60 @@ avi_reader_c::parse_subtitle_chunks() {
 
 void
 avi_reader_c::create_packetizer(int64_t tid) {
-  if ((0 == tid) && demuxing_requested('v', 0) && (-1 == m_vptzr)) {
-    int i;
+  if ((0 == tid) && demuxing_requested('v', 0) && (-1 == m_vptzr) && m_video_track_ok)
+    create_video_packetizer();
 
-    mxverb_tid(4, m_ti.m_fname, 0, "frame sizes:\n");
+  else if ((0 != tid) && (tid <= AVI_audio_tracks(m_avi)) && demuxing_requested('a', tid))
+    add_audio_demuxer(tid - 1);
+}
 
-    for (i = 0; i < m_max_video_frames; i++) {
-      m_bytes_to_process += AVI_frame_size(m_avi, i);
-      mxverb(4, boost::format("  %1%: %2%\n") % i % AVI_frame_size(m_avi, i));
-    }
+void
+avi_reader_c::create_video_packetizer() {
+  size_t i;
 
-    m_ti.m_private_data = (unsigned char *)m_avi->bitmap_info_header;
-    if (NULL != m_ti.m_private_data)
-      m_ti.m_private_size = get_uint32_le(&m_avi->bitmap_info_header->bi_size);
+  mxverb_tid(4, m_ti.m_fname, 0, "frame sizes:\n");
 
-    mxverb(4, boost::format("track extra data size: %1%\n") % (m_ti.m_private_size - sizeof(alBITMAPINFOHEADER)));
-    if (sizeof(alBITMAPINFOHEADER) < m_ti.m_private_size) {
-      mxverb(4, "  ");
-      for (i = sizeof(alBITMAPINFOHEADER); i < m_ti.m_private_size; ++i)
-        mxverb(4, boost::format("%|1$02x| ") % m_ti.m_private_data[i]);
-      mxverb(4, "\n");
-    }
-
-    const char *codec = AVI_video_compressor(m_avi);
-    if (mpeg4::p2::is_v3_fourcc(codec))
-      m_divx_type = DIVX_TYPE_V3;
-    else if (mpeg4::p2::is_fourcc(codec))
-      m_divx_type = DIVX_TYPE_MPEG4;
-
-    m_ti.m_id = 0;                 // ID for the video track.
-    if (DIVX_TYPE_MPEG4 == m_divx_type)
-      create_mpeg4_p2_packetizer();
-
-    else if (mpeg4::p10::is_avc_fourcc(codec) && !hack_engaged(ENGAGE_ALLOW_AVC_IN_VFW_MODE))
-      create_mpeg4_p10_packetizer();
-
-    else if (mpeg1_2::is_fourcc(get_uint32_le(codec)))
-      create_mpeg1_2_packetizer();
-
-    else
-      create_standard_video_packetizer();
+  for (i = 0; i < m_max_video_frames; i++) {
+    m_bytes_to_process += AVI_frame_size(m_avi, i);
+    mxverb(4, boost::format("  %1%: %2%\n") % i % AVI_frame_size(m_avi, i));
   }
 
-  if (0 == tid)
-    return;
+  m_ti.m_private_data = (unsigned char *)m_avi->bitmap_info_header;
+  if (NULL != m_ti.m_private_data)
+    m_ti.m_private_size = get_uint32_le(&m_avi->bitmap_info_header->bi_size);
 
-  if ((tid <= AVI_audio_tracks(m_avi)) && demuxing_requested('a', tid))
-    add_audio_demuxer(tid - 1);
+  mxverb(4, boost::format("track extra data size: %1%\n") % (m_ti.m_private_size - sizeof(alBITMAPINFOHEADER)));
+  if (sizeof(alBITMAPINFOHEADER) < m_ti.m_private_size) {
+    mxverb(4, "  ");
+    for (i = sizeof(alBITMAPINFOHEADER); i < m_ti.m_private_size; ++i)
+      mxverb(4, boost::format("%|1$02x| ") % m_ti.m_private_data[i]);
+    mxverb(4, "\n");
+  }
+
+  const char *codec = AVI_video_compressor(m_avi);
+  if (mpeg4::p2::is_v3_fourcc(codec))
+    m_divx_type = DIVX_TYPE_V3;
+  else if (mpeg4::p2::is_fourcc(codec))
+    m_divx_type = DIVX_TYPE_MPEG4;
+
+  if (map_has_key(m_ti.m_default_durations, 0))
+    m_fps = 1000000000.0 / m_ti.m_default_durations[0];
+
+  else if (map_has_key(m_ti.m_default_durations, -1))
+    m_fps = 1000000000.0 / m_ti.m_default_durations[-1];
+
+  m_ti.m_id = 0;                 // ID for the video track.
+  if (DIVX_TYPE_MPEG4 == m_divx_type)
+    create_mpeg4_p2_packetizer();
+
+  else if (mpeg4::p10::is_avc_fourcc(codec) && !hack_engaged(ENGAGE_ALLOW_AVC_IN_VFW_MODE))
+    create_mpeg4_p10_packetizer();
+
+  else if (mpeg1_2::is_fourcc(get_uint32_le(codec)))
+    create_mpeg1_2_packetizer();
+
+  else
+    create_standard_video_packetizer();
 }
 
 void
@@ -248,9 +272,9 @@ avi_reader_c::create_mpeg1_2_packetizer() {
   if ((0 != m_ti.m_private_size) && (m_ti.m_private_size < sizeof(alBITMAPINFOHEADER)))
     m2v_parser->WriteData(m_ti.m_private_data + sizeof(alBITMAPINFOHEADER), m_ti.m_private_size - sizeof(alBITMAPINFOHEADER));
 
-  int frame_number = 0;
-  int state        = m2v_parser->GetState();
-  while ((frame_number < std::min(m_max_video_frames, 100)) && (MPV_PARSER_STATE_FRAME != state)) {
+  unsigned int frame_number = 0;
+  unsigned int state        = m2v_parser->GetState();
+  while ((frame_number < std::min(m_max_video_frames, 100u)) && (MPV_PARSER_STATE_FRAME != state)) {
     ++frame_number;
 
     int size = AVI_frame_size(m_avi, frame_number - 1);
@@ -301,7 +325,7 @@ avi_reader_c::create_mpeg1_2_packetizer() {
 
 void
 avi_reader_c::create_mpeg4_p2_packetizer() {
-  m_vptzr = add_packetizer(new mpeg4_p2_video_packetizer_c(this, m_ti, AVI_frame_rate(m_avi), AVI_video_width(m_avi), AVI_video_height(m_avi), false));
+  m_vptzr = add_packetizer(new mpeg4_p2_video_packetizer_c(this, m_ti, m_fps, AVI_video_width(m_avi), AVI_video_height(m_avi), false));
 
   if (verbose)
     mxinfo_tid(m_ti.m_fname, 0, Y("Using the MPEG-4 part 2 video output module.\n"));
@@ -315,7 +339,7 @@ avi_reader_c::create_mpeg4_p10_packetizer() {
     m_vptzr                               = add_packetizer(ptzr);
 
     ptzr->enable_timecode_generation(false);
-    ptzr->set_track_default_duration((int64_t)(1000000000 / AVI_frame_rate(m_avi)));
+    ptzr->set_track_default_duration((int64_t)(1000000000 / m_fps));
 
     if (m_avc_extra_nalus.is_set())
       ptzr->add_extra_data(m_avc_extra_nalus);
@@ -330,7 +354,7 @@ avi_reader_c::create_mpeg4_p10_packetizer() {
 
 void
 avi_reader_c::create_standard_video_packetizer() {
-  m_vptzr = add_packetizer(new video_packetizer_c(this, m_ti, NULL, AVI_frame_rate(m_avi), AVI_video_width(m_avi), AVI_video_height(m_avi)));
+  m_vptzr = add_packetizer(new video_packetizer_c(this, m_ti, NULL, m_fps, AVI_video_width(m_avi), AVI_video_height(m_avi)));
 
   if (verbose)
     mxinfo_tid(m_ti.m_fname, 0, Y("Using the video output module.\n"));
@@ -345,7 +369,7 @@ avi_reader_c::create_packetizers() {
   for (i = 0; i < AVI_audio_tracks(m_avi); i++)
     create_packetizer(i + 1);
 
-  for (i = 0; m_subtitle_demuxers.size() > i; ++i)
+  for (i = 0; static_cast<int>(m_subtitle_demuxers.size()) > i; ++i)
     create_subs_packetizer(i);
 }
 
@@ -389,8 +413,8 @@ avi_reader_c::create_ssa_packetizer(int idx) {
   ssa_parser_c *parser           = new ssa_parser_c(this, demuxer.m_text_io.get_object(), m_ti.m_fname, id);
   demuxer.m_subs                 = subtitles_cptr(parser);
 
-  charset_converter_cptr cc_utf8 = map_has_key(m_ti.m_sub_charsets, id)               ? charset_converter_c::init(m_ti.m_sub_charsets[id])
-                                 : map_has_key(m_ti.m_sub_charsets, -1)               ? charset_converter_c::init(m_ti.m_sub_charsets[-1])
+  charset_converter_cptr cc_utf8 = map_has_key(m_ti.m_sub_charsets, id)           ? charset_converter_c::init(m_ti.m_sub_charsets[id])
+                                 : map_has_key(m_ti.m_sub_charsets, -1)           ? charset_converter_c::init(m_ti.m_sub_charsets[-1])
                                  : demuxer.m_text_io->get_byte_order() != BO_NONE ? charset_converter_c::init("UTF-8")
                                  :                                                  g_cc_local_utf8;
 
@@ -418,12 +442,14 @@ avi_reader_c::extract_avcc() {
   if (0 < extra_data_size) {
     m_avc_extra_nalus = mpeg4::p10::avcc_to_nalus((unsigned char *)(m_avi->bitmap_info_header + 1), extra_data_size);
     if (m_avc_extra_nalus.is_set()) {
-      m_avc_nal_size_size = 1 + (((unsigned char *)(m_avi->bitmap_info_header + 1))[4] & 0x03);
+      uint32_t marker = get_uint32_be(m_avi->bitmap_info_header + 1);
+      if ((0x00000001 != marker) && (0x00000100 != (marker & 0xffffff00)))
+        m_avc_nal_size_size = 1 + (((unsigned char *)(m_avi->bitmap_info_header + 1))[4] & 0x03);
       parser.add_bytes(m_avc_extra_nalus->get_buffer(), m_avc_extra_nalus->get_size());
     }
   }
 
-  int i;
+  size_t i;
   for (i = 0; i < m_max_video_frames; ++i) {
     int size = AVI_frame_size(m_avi, i);
     if (0 == size)
@@ -538,17 +564,9 @@ avi_reader_c::add_audio_demuxer(int aid) {
         mxinfo_tid(m_ti.m_fname, aid + 1, Y("Using the AC3 output module.\n"));
       break;
 
-    case 0x2001: {              // DTS
-      dts_header_t dtsheader;
-
-      dtsheader.core_sampling_frequency = demuxer.m_samples_per_second;
-      dtsheader.audio_channels          = demuxer.m_channels;
-      packetizer                        = new dts_packetizer_c(this, m_ti, dtsheader, true);
-
-      if (verbose)
-        mxinfo_tid(m_ti.m_fname, aid + 1, Y("Using the DTS output module.\n"));
+    case 0x2001:                // DTS
+      packetizer = create_dts_packetizer(aid);
       break;
-    }
 
     case 0x00ff:
     case 0x706d:                // AAC
@@ -631,6 +649,44 @@ avi_reader_c::create_aac_packetizer(int aid,
   return packetizer;
 }
 
+generic_packetizer_c *
+avi_reader_c::create_dts_packetizer(int aid) {
+  try {
+    AVI_set_audio_track(m_avi, aid);
+
+    long audio_position   = AVI_get_audio_position_index(m_avi);
+    unsigned int num_read = 0;
+    int dts_position      = -1;
+    byte_buffer_c buffer;
+    dts_header_t dtsheader;
+
+    while ((-1 == dts_position) && (10 > num_read)) {
+      memory_cptr chunk = memory_c::alloc(AVI_read_audio_chunk(m_avi, NULL));
+      if (AVI_read_audio_chunk(m_avi, reinterpret_cast<char *>(chunk->get_buffer())) < 0)
+        throw false;
+
+      buffer.add(chunk);
+      dts_position = find_dts_header(buffer.get_buffer(), buffer.get_size(), &dtsheader);
+    }
+
+    if (-1 == dts_position)
+      throw false;
+
+    AVI_set_audio_position_index(m_avi, audio_position);
+
+    generic_packetizer_c *packetizer = new dts_packetizer_c(this, m_ti, dtsheader, true);
+
+    if (verbose)
+      mxinfo_tid(m_ti.m_fname, aid + 1, Y("Using the DTS output module.\n"));
+
+    return packetizer;
+
+  } catch (...) {
+    mxerror_tid(m_ti.m_fname, aid + 1, Y("Could not find valid DTS headers in this track's first frames.\n"));
+    return NULL;
+  }
+}
+
 generic_packetizer_c *
 avi_reader_c::create_vorbis_packetizer(int aid) {
   try {
@@ -690,7 +746,7 @@ avi_reader_c::create_vorbis_packetizer(int aid) {
 file_status_e
 avi_reader_c::read_video() {
   if (m_video_frames_read >= m_max_video_frames)
-    return FILE_STATUS_DONE;
+    return flush_packetizer(m_vptzr);
 
   memory_cptr chunk;
   int key                   = 0;
@@ -710,7 +766,7 @@ avi_reader_c::read_video() {
     if (0 > num_read) {
       // Error reading the frame: abort
       m_video_frames_read = m_max_video_frames;
-      return FILE_STATUS_DONE;
+      return flush_packetizer(m_vptzr);
 
     } else if (0 == num_read)
       ++dropped_frames_here;
@@ -719,9 +775,9 @@ avi_reader_c::read_video() {
 
   if (0 == num_read)
     // This is only the case if the AVI contains dropped frames only.
-    return FILE_STATUS_DONE;
+    return flush_packetizer(m_vptzr);
 
-  int i;
+  size_t i;
   for (i = m_video_frames_read; i < m_max_video_frames; ++i) {
     if (0 != AVI_frame_size(m_avi, i))
       break;
@@ -764,12 +820,7 @@ avi_reader_c::read_video() {
 
   m_bytes_processed += num_read;
 
-  if (m_video_frames_read >= m_max_video_frames) {
-    PTZR(m_vptzr)->flush();
-    return FILE_STATUS_DONE;
-  }
-
-  return FILE_STATUS_MOREDATA;
+  return m_video_frames_read >= m_max_video_frames ? flush_packetizer(m_vptzr) :  FILE_STATUS_MOREDATA;
 }
 
 file_status_e
@@ -777,18 +828,14 @@ avi_reader_c::read_audio(avi_demuxer_t &demuxer) {
   AVI_set_audio_track(m_avi, demuxer.m_aid);
   int size = AVI_read_audio_chunk(m_avi, NULL);
 
-  if (0 >= size) {
-    PTZR(demuxer.m_ptzr)->flush();
-    return FILE_STATUS_DONE;
-  }
+  if (0 >= size)
+    return flush_packetizer(demuxer.m_ptzr);
 
   memory_cptr chunk = memory_c::alloc(size);
   size              = AVI_read_audio_chunk(m_avi, (char *)chunk->get_buffer());
 
-  if (0 >= size) {
-    PTZR(demuxer.m_ptzr)->flush();
-    return FILE_STATUS_DONE;
-  }
+  if (0 >= size)
+    return flush_packetizer(demuxer.m_ptzr);
 
   bool need_more_data = 0 != AVI_read_audio_chunk(m_avi, NULL);
 
@@ -797,27 +844,15 @@ avi_reader_c::read_audio(avi_demuxer_t &demuxer) {
 
   m_bytes_processed += size;
 
-  if (need_more_data)
-    return FILE_STATUS_MOREDATA;
-  else {
-    PTZR(demuxer.m_ptzr)->flush();
-    return FILE_STATUS_DONE;
-  }
+  return need_more_data ? FILE_STATUS_MOREDATA : flush_packetizer(demuxer.m_ptzr);
 }
 
 file_status_e
 avi_reader_c::read_subtitles(avi_subs_demuxer_t &demuxer) {
-  if (demuxer.m_subs->empty())
-    return FILE_STATUS_DONE;
+  if (!demuxer.m_subs->empty())
+    demuxer.m_subs->process(PTZR(demuxer.m_ptzr));
 
-  demuxer.m_subs->process(PTZR(demuxer.m_ptzr));
-
-  if (demuxer.m_subs->empty()) {
-    PTZR(demuxer.m_ptzr)->flush();
-    return FILE_STATUS_DONE;
-  }
-
-  return FILE_STATUS_MOREDATA;
+  return demuxer.m_subs->empty() ? flush_packetizer(demuxer.m_ptzr) : FILE_STATUS_MOREDATA;
 }
 
 file_status_e
@@ -836,7 +871,7 @@ avi_reader_c::read(generic_packetizer_c *ptzr,
     if ((-1 != subs_demuxer->m_ptzr) && (PTZR(subs_demuxer->m_ptzr) == ptzr))
       return read_subtitles(*subs_demuxer);
 
-  return FILE_STATUS_DONE;
+  return flush_packetizers();
 }
 
 int
@@ -878,6 +913,7 @@ avi_reader_c::extended_identify_mpeg4_l2(std::vector<std::string> &extended_info
 
 void
 avi_reader_c::identify() {
+  id_result_container("AVI");
   identify_video();
   identify_audio();
   identify_subtitles();
@@ -886,9 +922,10 @@ avi_reader_c::identify() {
 
 void
 avi_reader_c::identify_video() {
-  std::vector<std::string> extended_info;
+  if (!m_video_track_ok)
+    return;
 
-  id_result_container("AVI");
+  std::vector<std::string> extended_info;
 
   const char *fourcc_str = AVI_video_compressor(m_avi);
   std::string type       = fourcc_str;
@@ -929,7 +966,7 @@ avi_reader_c::identify_audio() {
 
 void
 avi_reader_c::identify_subtitles() {
-  int i;
+  size_t i;
   for (i = 0; m_subtitle_demuxers.size() > i; ++i)
     id_result_track(1 + AVI_audio_tracks(m_avi) + i, ID_RESULT_TRACK_SUBTITLES,
                       avi_subs_demuxer_t::TYPE_SRT == m_subtitle_demuxers[i].m_type ? "SRT"
@@ -939,7 +976,7 @@ avi_reader_c::identify_subtitles() {
 
 void
 avi_reader_c::identify_attachments() {
-  int i;
+  size_t i;
 
   for (i = 0; m_subtitle_demuxers.size() > i; ++i) {
     try {
@@ -960,7 +997,7 @@ avi_reader_c::identify_attachments() {
 
 void
 avi_reader_c::add_available_track_ids() {
-  int i;
+  size_t i;
 
   // Yes, '>=' is correct. Don't forget the video track!
   for (i = 0; (AVI_audio_tracks(m_avi) + m_subtitle_demuxers.size()) >= i; i++)
@@ -971,7 +1008,7 @@ void
 avi_reader_c::debug_dump_video_index() {
   int num_video_frames = AVI_video_frames(m_avi), i;
 
-  mxinfo(boost::format("AVI video index dump: %1% entries; frame rate: %2%\n") % num_video_frames % AVI_frame_rate(m_avi));
+  mxinfo(boost::format("AVI video index dump: %1% entries; frame rate: %2%\n") % num_video_frames % m_fps);
   for (i = 0; num_video_frames > i; ++i)
     mxinfo(boost::format("  %1%: %2% bytes\n") % i % AVI_frame_size(m_avi, i));
 }
