@@ -15,6 +15,7 @@
 #include "common/common_pch.h"
 
 #include <avilib.h>   // for BITMAPINFOHEADER
+#include <boost/math/common_factor.hpp>
 
 #include <ebml/EbmlContexts.h>
 #include <ebml/EbmlHead.h>
@@ -68,6 +69,7 @@
 #include "output/p_mpeg4_p10.h"
 #include "output/p_passthrough.h"
 #include "output/p_pcm.h"
+#include "output/p_pgs.h"
 #include "output/p_textsubs.h"
 #include "output/p_theora.h"
 #include "output/p_tta.h"
@@ -136,13 +138,42 @@ kax_track_t::handle_packetizer_default_duration() {
     ptzr_ptr->set_track_default_duration(default_duration);
 }
 
+/* Fix display dimension parameters
+
+   Certain Matroska muxers abuse the DisplayWidth/DisplayHeight
+   parameters for only storing an aspect ratio. These values are
+   usually very small, e.g. 16/9. Fix them so that the quotient is
+   kept but the values are in the range of the PixelWidth/PixelHeight
+   elements.
+ */
+void
+kax_track_t::fix_display_dimension_parameters() {
+  if (0 != v_display_unit)
+    return;
+
+  if (((8 * v_dwidth) > v_width) || ((8 * v_dheight) > v_height))
+    return;
+
+  if (boost::math::gcd(v_dwidth, v_dheight) == 1) { // max shrinking was applied, ie x264 style
+    if (v_dwidth > v_dheight) {
+      if (((v_height * v_dwidth) % v_dheight) == 0) { // only if we get get an exact count of pixels
+        v_dwidth  = v_height * v_dwidth / v_dheight;
+        v_dheight = v_height;
+      }
+    } else if (((v_width * v_dheight) % v_dwidth) == 0) {
+      v_dwidth  = v_width;
+      v_dheight = v_width * v_dheight / v_dwidth;
+    }
+  }
+}
+
 /*
    Probes a file by simply comparing the first four bytes to the EBML
    head signature.
 */
 int
 kax_reader_c::probe_file(mm_io_c *io,
-                         int64_t size) {
+                         uint64_t size) {
   unsigned char data[4];
 
   if (4 > size)
@@ -164,6 +195,7 @@ kax_reader_c::kax_reader_c(track_info_c &_ti)
   throw (error_c)
   : generic_reader_c(_ti)
   , m_segment_duration(0)
+  , m_last_timecode(0)
   , m_first_timecode(-1)
   , m_writing_app_ver(-1)
   , m_attachment_id(0)
@@ -351,7 +383,7 @@ kax_reader_c::verify_audio_track(kax_track_t *t) {
   bool is_ok = true;
   if (t->codec_id == MKV_A_ACM)
     is_ok = verify_acm_audio_track(t);
-  else if (starts_with(t->codec_id, MKV_A_MP3, strlen(MKV_A_MP3) - 1))
+  else if ((t->codec_id == MKV_A_MP3) || (t->codec_id == MKV_A_MP2))
     t->a_formattag = 0x0055;
   else if (starts_with(t->codec_id, MKV_A_AC3, strlen(MKV_A_AC3)) || (t->codec_id == MKV_A_EAC3))
     t->a_formattag = 0x2000;
@@ -522,7 +554,7 @@ kax_reader_c::verify_button_track(kax_track_t *t) {
 
 void
 kax_reader_c::verify_tracks() {
-  int tnum;
+  size_t tnum;
   kax_track_t *t;
 
   for (tnum = 0; tnum < m_tracks.size(); tnum++) {
@@ -600,7 +632,7 @@ kax_reader_c::handle_attachments(mm_io_c *io,
 
     atts->Read(*m_es, EBML_CLASS_CONTEXT(KaxAttachments), upper_lvl_el, l2, true);
 
-    int i;
+    size_t i;
     for (i = 0; i < atts->ListSize(); i++) {
       KaxAttached *att = (KaxAttached *)(*atts)[i];
 
@@ -611,7 +643,7 @@ kax_reader_c::handle_attachments(mm_io_c *io,
         int64_t size          = -1;
         int64_t id            = -1;
         unsigned char *data   = NULL;
-        int k;
+        size_t k;
 
         for (k = 0; k < att->ListSize(); k++) {
           l2 = (*att)[k];
@@ -684,7 +716,7 @@ kax_reader_c::handle_chapters(mm_io_c *io,
     if (NULL == m_chapters)
       m_chapters = new KaxChapters;
 
-    int i;
+    size_t i;
     for (i = 0; i < tmp_chapters->ListSize(); i++)
       m_chapters->PushElement(*(*tmp_chapters)[i]);
     tmp_chapters->RemoveAll();
@@ -736,7 +768,7 @@ kax_reader_c::handle_tags(mm_io_c *io,
           if (NULL != track) {
             bool contains_tag = false;
 
-            int i;
+            size_t i;
             for (i = 0; i < tag->ListSize(); i++)
               if (dynamic_cast<KaxTagSimple *>((*tag)[i]) != NULL) {
                 contains_tag = true;
@@ -834,7 +866,7 @@ kax_reader_c::read_headers_info(EbmlElement *&l1,
 
 void
 kax_reader_c::read_headers_info_writing_app(KaxWritingApp *&km_writing_app) {
-  int idx;
+  size_t idx;
 
   std::string s = UTFstring_to_cstrutf8(UTFstring(*km_writing_app));
   strip(s);
@@ -948,6 +980,16 @@ kax_reader_c::read_headers_track_video(kax_track_t *&track,
   } else
     track->v_dheight = track->v_height;
 
+#if MATROSKA_VERSION >= 2
+  KaxVideoDisplayUnit *kv_dunit = FINDFIRST(ktvideo, KaxVideoDisplayUnit);
+  if (NULL != kv_dunit) {
+    track->v_display_unit = uint64(*kv_dunit);
+    mxverb(2, boost::format("matroska_reader: |   + Display unit: %1%\n") % track->v_display_unit);
+  }
+#endif
+
+  track->fix_display_dimension_parameters();
+
   // For older files.
   KaxVideoFrameRate *kv_frate = FINDFIRST(ktvideo, KaxVideoFrameRate);
   if (NULL != kv_frate) {
@@ -1108,8 +1150,7 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
     if (NULL != ktflacing) {
       mxverb(2, boost::format("matroska_reader: |  + Lacing flag: %1%\n") % uint64(*ktflacing));
       track->lacing_flag = uint64(*ktflacing);
-    } else
-      track->lacing_flag = true;
+    }
 
     KaxMaxBlockAdditionID *ktmax_blockadd_id = FINDFIRST(ktentry, KaxMaxBlockAdditionID);
     if (NULL != ktmax_blockadd_id) {
@@ -1148,14 +1189,14 @@ kax_reader_c::read_headers_seek_head(EbmlElement *&l0,
   int i = 0;
   seek_head.Read(*m_es, EBML_CLASS_CONTEXT(KaxSeekHead), i, el, true);
 
-  for (i = 0; i < seek_head.ListSize(); i++) {
+  for (i = 0; i < static_cast<int>(seek_head.ListSize()); i++) {
     if (EbmlId(*seek_head[i]) != EBML_ID(KaxSeek))
       continue;
 
     KaxSeek &seek           = *static_cast<KaxSeek *>(seek_head[i]);
     int64_t pos             = -1;
     deferred_l1_type_e type = dl1t_unknown;
-    int k;
+    size_t k;
 
     for (k = 0; k < seek.ListSize(); k++)
       if (EbmlId(*seek[k]) == EBML_ID(KaxSeekID)) {
@@ -1203,6 +1244,7 @@ kax_reader_c::read_headers() {
 
     // Next element must be a segment
     l0 = m_es->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
+    counted_ptr<EbmlElement> l0_cptr(l0);
     if (NULL == l0) {
       if (verbose)
         mxwarn(Y("matroska_reader: No segment found.\n"));
@@ -1317,7 +1359,7 @@ kax_reader_c::process_global_tags() {
   if (!m_tags.is_set() || g_identifying)
     return;
 
-  int i;
+  size_t i;
   for (i = 0; m_tags->ListSize() > i; ++i)
     add_tags(static_cast<KaxTag *>((*m_tags)[i]));
 
@@ -1513,13 +1555,25 @@ kax_reader_c::create_ac3_audio_packetizer(kax_track_t *t,
 void
 kax_reader_c::create_dts_audio_packetizer(kax_track_t *t,
                                           track_info_c &nti) {
-  dts_header_t dtsheader;
+  try {
+    read_first_frames(t, 5);
 
-  dtsheader.core_sampling_frequency = (unsigned int)t->a_sfreq;
-  dtsheader.audio_channels          = t->a_channels;
+    byte_buffer_c buffer;
+    foreach(memory_cptr &frame, t->first_frames_data)
+      buffer.add(frame);
 
-  t->ptzr = add_packetizer(new dts_packetizer_c(this, nti, dtsheader, true));
-  mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the DTS output module.\n"));
+    dts_header_t dtsheader;
+    int position = find_dts_header(buffer.get_buffer(), buffer.get_size(), &dtsheader);
+
+    if (-1 == position)
+      throw false;
+
+    t->ptzr = add_packetizer(new dts_packetizer_c(this, nti, dtsheader, true));
+    mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the DTS output module.\n"));
+
+  } catch (...) {
+    mxerror_tid(m_ti.m_fname, t->tnum, Y("Could not find valid DTS headers in this track's first frames.\n"));
+  }
 }
 
 #if defined(HAVE_FLAC_FORMAT_H)
@@ -1658,6 +1712,12 @@ kax_reader_c::create_subtitle_packetizer(kax_track_t *t,
 
     mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the Kate output module.\n"));
 
+  } else if (t->codec_id == MKV_S_HDMV_PGS) {
+    t->ptzr     = add_packetizer(new pgs_packetizer_c(this, nti));
+    t->sub_type = 'p';
+
+    mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the PGS output module.\n"));
+
   } else
     init_passthrough_packetizer(t);
 
@@ -1812,7 +1872,7 @@ kax_reader_c::read_first_frames(kax_track_t *t,
   if (t->first_frames_data.size() >= num_wanted)
     return;
 
-  std::map<int64_t, int> frames_by_track_id;
+  std::map<int64_t, unsigned int> frames_by_track_id;
 
   m_in->save_pos();
 
@@ -1826,7 +1886,7 @@ kax_reader_c::read_first_frames(kax_track_t *t,
       if (NULL != ctc)
         cluster->InitTimecode(uint64(*ctc), m_tc_scale);
 
-      int bgidx;
+      size_t bgidx;
       for (bgidx = 0; bgidx < cluster->ListSize(); bgidx++) {
         if ((EbmlId(*(*cluster)[bgidx]) == EBML_ID(KaxSimpleBlock))) {
           KaxSimpleBlock *block_simple = static_cast<KaxSimpleBlock *>((*cluster)[bgidx]);
@@ -1837,7 +1897,7 @@ kax_reader_c::read_first_frames(kax_track_t *t,
           if ((NULL == block_track) || (0 == block_simple->NumberFrames()))
             continue;
 
-          for (int frame_idx = 0; block_simple->NumberFrames() > frame_idx; ++frame_idx) {
+          for (size_t frame_idx = 0; block_simple->NumberFrames() > frame_idx; ++frame_idx) {
             frames_by_track_id[ block_simple->TrackNum() ]++;
 
             if (frames_by_track_id[ block_simple->TrackNum() ] <= block_track->first_frames_data.size())
@@ -1862,7 +1922,7 @@ kax_reader_c::read_first_frames(kax_track_t *t,
           if ((NULL == block_track) || (0 == block->NumberFrames()))
             continue;
 
-          for (int frame_idx = 0; block->NumberFrames() > frame_idx; ++frame_idx) {
+          for (size_t frame_idx = 0; block->NumberFrames() > frame_idx; ++frame_idx) {
             frames_by_track_id[ block->TrackNum() ]++;
 
             if (frames_by_track_id[ block->TrackNum() ] <= block_track->first_frames_data.size())
@@ -1922,7 +1982,7 @@ kax_reader_c::read(generic_packetizer_c *requested_ptzr,
         adjust_chapter_timecodes(*m_chapters, -m_first_timecode);
     }
 
-    int bgidx;
+    size_t bgidx;
     for (bgidx = 0; bgidx < cluster->ListSize(); bgidx++) {
       EbmlElement *element = (*cluster)[bgidx];
 
@@ -1999,9 +2059,10 @@ kax_reader_c::process_simple_block(KaxCluster *cluster,
     // and stuff. Just pass everything through as it is.
     int i;
     for (i = 0; i < (int)block_simple->NumberFrames(); i++) {
-      DataBuffer &data = block_simple->GetBuffer(i);
-      packet_t *packet = new packet_t(new memory_c((unsigned char *)data.Buffer(), data.Size(), false),
-                                      m_last_timecode + i * frame_duration, block_duration, block_bref, block_fref);
+      DataBuffer &data_buffer = block_simple->GetBuffer(i);
+      memory_cptr data(new memory_c(data_buffer.Buffer(), data_buffer.Size(), false));
+      block_track->content_decoder.reverse(data, CONTENT_ENCODING_SCOPE_BLOCK);
+      packet_t *packet = new packet_t(data, m_last_timecode + i * frame_duration, block_duration, block_bref, block_fref);
 
       ((passthrough_packetizer_c *)PTZR(block_track->ptzr))->process(packet_cptr(packet));
     }
@@ -2015,11 +2076,11 @@ kax_reader_c::process_simple_block(KaxCluster *cluster,
 
       if (('s' == block_track->type) && ('t' == block_track->sub_type)) {
         if ((2 < data->get_size()) || ((0 < data->get_size()) && (' ' != *data->get_buffer()) && (0 != *data->get_buffer()) && !iscr(*data->get_buffer()))) {
-          char *lines             = (char *)safemalloc(data->get_size() + 1);
-          lines[data->get_size()] = 0;
-          memcpy(lines, data->get_buffer(), data->get_size());
+          memory_cptr lines = memory_c::alloc(data->get_size() + 1);
+          lines->get_buffer()[ data->get_size() ] = 0;
+          memcpy(lines->get_buffer(), data->get_buffer(), data->get_size());
 
-          PTZR(block_track->ptzr)-> process(new packet_t(new memory_c((unsigned char *)lines, 0, true), m_last_timecode, block_duration, block_bref, block_fref));
+          PTZR(block_track->ptzr)->process(new packet_t(lines, m_last_timecode, block_duration, block_bref, block_fref));
         }
 
       } else {
@@ -2110,9 +2171,10 @@ kax_reader_c::process_block_group(KaxCluster *cluster,
 
     int i;
     for (i = 0; i < (int)block->NumberFrames(); i++) {
-      DataBuffer &data           = block->GetBuffer(i);
-      packet_t *packet           = new packet_t(new memory_c((unsigned char *)data.Buffer(), data.Size(), false),
-                                                m_last_timecode + i * frame_duration, block_duration, block_bref, block_fref);
+      DataBuffer &data_buffer = block->GetBuffer(i);
+      memory_cptr data(new memory_c(data_buffer.Buffer(), data_buffer.Size(), false));
+      block_track->content_decoder.reverse(data, CONTENT_ENCODING_SCOPE_BLOCK);
+      packet_t *packet           = new packet_t(data, m_last_timecode + i * frame_duration, block_duration, block_bref, block_fref);
       packet->duration_mandatory = duration != NULL;
 
       if (NULL != codec_state)
@@ -2157,7 +2219,7 @@ kax_reader_c::process_block_group(KaxCluster *cluster,
           packet->codec_state = clone_memory(codec_state->GetBuffer(), codec_state->GetSize());
 
         if (blockadd) {
-          int k;
+          size_t k;
           for (k = 0; k < blockadd->ListSize(); k++) {
             if (!(is_id((*blockadd)[k], KaxBlockMore)))
               continue;
@@ -2184,7 +2246,7 @@ kax_reader_c::process_block_group(KaxCluster *cluster,
 int
 kax_reader_c::get_progress() {
   if (0 != m_segment_duration)
-    return (m_last_timecode - m_first_timecode) * 100 / m_segment_duration;
+    return (m_last_timecode - std::max(m_first_timecode, static_cast<int64_t>(0))) * 100 / m_segment_duration;
 
   return 100 * m_in->getFilePointer() / m_file_size;
 }
