@@ -51,6 +51,7 @@ struct kax_track_t {
 
   // Parameters for video tracks
   uint64_t v_width, v_height, v_dwidth, v_dheight;
+  unsigned int v_display_unit;
   uint64_t v_pcleft, v_pctop, v_pcright, v_pcbottom;
   stereo_mode_e v_stereo_mode;
   float v_frate;
@@ -99,12 +100,13 @@ struct kax_track_t {
     , passthrough(false)
     , min_cache(0)
     , max_cache(0)
-    , lacing_flag(false)
+    , lacing_flag(true)
     , default_duration(0)
     , v_width(0)
     , v_height(0)
     , v_dwidth(0)
     , v_dheight(0)
+    , v_display_unit(0)
     , v_pcleft(0)
     , v_pctop(0)
     , v_pcright(0)
@@ -115,11 +117,11 @@ struct kax_track_t {
     , a_channels(0)
     , a_bps(0)
     , a_formattag(0)
-    , a_sfreq(0.0)
+    , a_sfreq(8000.0)
     , a_osfreq(0.0)
     , private_data(NULL)
     , private_size(0)
-    , default_track(false)
+    , default_track(true)
     , forced_track(boost::logic::indeterminate)
     , language("eng")
     , units_processed(0)
@@ -147,6 +149,7 @@ struct kax_track_t {
   void handle_packetizer_stereo_mode();
   void handle_packetizer_pixel_dimensions();
   void handle_packetizer_default_duration();
+  void fix_display_dimension_parameters();
 };
 typedef counted_ptr<kax_track_t> kax_track_cptr;
 
@@ -199,7 +202,7 @@ public:
   virtual void create_packetizer(int64_t tid);
   virtual void add_available_track_ids();
 
-  static int probe_file(mm_io_c *io, int64_t size);
+  static int probe_file(mm_io_c *io, uint64_t size);
 
 protected:
   virtual void set_track_packetizer(kax_track_t *t, generic_packetizer_c *ptzr);
