@@ -409,7 +409,7 @@ wav_pcm_demuxer_c::process(int64_t len) {
 
 int
 wav_reader_c::probe_file(mm_io_c *io,
-                         int64_t size) {
+                         uint64_t size) {
   wave_header wheader;
 
   if (sizeof(wave_header) > size)
@@ -548,7 +548,7 @@ wav_reader_c::create_demuxer() {
 
 void
 wav_reader_c::create_packetizer(int64_t) {
-  if (NPTZR() != 0)
+  if (!demuxing_requested('a', 0) || (NPTZR() != 0))
     return;
 
   add_packetizer(m_demuxer->create_packetizer());
@@ -563,10 +563,8 @@ wav_reader_c::read(generic_packetizer_c *,
 
   num_read = m_io->read(buffer, requested_bytes);
 
-  if (0 >= num_read) {
-    PTZR0->flush();
-    return FILE_STATUS_DONE;
-  }
+  if (0 >= num_read)
+    return flush_packetizers();
 
   m_demuxer->process(num_read);
 
@@ -576,10 +574,8 @@ wav_reader_c::read(generic_packetizer_c *,
   if (!m_remaining_bytes_in_current_data_chunk) {
     m_cur_data_chunk_idx = find_chunk("data", m_cur_data_chunk_idx + 1, false);
 
-    if (-1 == m_cur_data_chunk_idx) {
-      PTZR0->flush();
-      return FILE_STATUS_DONE;
-    }
+    if (-1 == m_cur_data_chunk_idx)
+      return flush_packetizers();
 
     m_io->setFilePointer(m_chunks[m_cur_data_chunk_idx].pos + sizeof(struct chunk_struct), seek_beginning);
 
@@ -638,7 +634,7 @@ int
 wav_reader_c::find_chunk(const char *id,
                          int start_idx,
                          bool allow_empty) {
-  int idx;
+  size_t idx;
 
   for (idx = start_idx; idx < m_chunks.size(); ++idx)
     if (!strncasecmp(m_chunks[idx].id, id, 4) && (allow_empty || m_chunks[idx].len))
