@@ -46,6 +46,7 @@
 #include "common/command_line.h"
 #include "common/ebml.h"
 #include "common/extern_data.h"
+#include "common/file_types.h"
 #include "common/fs_sys_helpers.h"
 #include "common/hacks.h"
 #include "common/iso639.h"
@@ -63,51 +64,6 @@
 
 using namespace libmatroska;
 
-struct ext_file_type_t {
-  std::string ext, desc;
-
-  ext_file_type_t(const std::string &p_ext,
-                  const std::string &p_desc)
-    : ext(p_ext)
-    , desc(p_desc)
-  {
-  }
-};
-
-static std::list<ext_file_type_t> s_input_file_types;
-
-static void
-init_input_file_type_list() {
-  s_input_file_types.push_back(ext_file_type_t("aac",  Y("AAC (Advanced Audio Coding)")));
-  s_input_file_types.push_back(ext_file_type_t("ac3",  Y("A/52 (aka AC3)")));
-  s_input_file_types.push_back(ext_file_type_t("avi",  Y("AVI (Audio/Video Interleaved)")));
-  s_input_file_types.push_back(ext_file_type_t("btn",  Y("VobBtn buttons")));
-  s_input_file_types.push_back(ext_file_type_t("drc",  Y("Dirac elementary stream")));
-  s_input_file_types.push_back(ext_file_type_t("dts",  Y("DTS (Digital Theater System)")));
-#if defined(HAVE_FLAC_FORMAT_H)
-  s_input_file_types.push_back(ext_file_type_t("flac", Y("FLAC lossless audio")));
-#endif
-  s_input_file_types.push_back(ext_file_type_t("h264", Y("AVC/h.264 elementary streams")));
-  s_input_file_types.push_back(ext_file_type_t("idx",  Y("VobSub subtitles")));
-  s_input_file_types.push_back(ext_file_type_t("ivf",  Y("IVF with VP8")));
-  s_input_file_types.push_back(ext_file_type_t("m1v",  Y("MPEG-1 video elementary stream")));
-  s_input_file_types.push_back(ext_file_type_t("m2v",  Y("MPEG-2 video elementary stream")));
-  s_input_file_types.push_back(ext_file_type_t("mkv",  Y("general Matroska files")));
-  s_input_file_types.push_back(ext_file_type_t("mov",  Y("Quicktime/MP4 audio and video")));
-  s_input_file_types.push_back(ext_file_type_t("mp2",  Y("MPEG-1 layer II audio (CBR and VBR/ABR)")));
-  s_input_file_types.push_back(ext_file_type_t("mp3",  Y("MPEG-1 layer III audio (CBR and VBR/ABR)")));
-  s_input_file_types.push_back(ext_file_type_t("mpg",  Y("MPEG program stream")));
-  s_input_file_types.push_back(ext_file_type_t("ogg",  Y("audio/video/text subtitles embedded in OGG")));
-  s_input_file_types.push_back(ext_file_type_t("rm",   Y("RealMedia audio and video")));
-  s_input_file_types.push_back(ext_file_type_t("srt",  Y("SRT text subtitles")));
-  s_input_file_types.push_back(ext_file_type_t("ssa",  Y("SSA/ASS text subtitles")));
-  s_input_file_types.push_back(ext_file_type_t("tta",  Y("TTA lossless audio")));
-  s_input_file_types.push_back(ext_file_type_t("vc1",  Y("VC1 video elementary stream")));
-  s_input_file_types.push_back(ext_file_type_t("wav",  Y("WAVE (uncompressed PCM)")));
-  s_input_file_types.push_back(ext_file_type_t("webm", Y("WebM audio/video files")));
-  s_input_file_types.push_back(ext_file_type_t("wv",   Y("WAVPACK lossless audio")));
-}
-
 /** \brief Outputs usage information
 */
 static void
@@ -323,7 +279,7 @@ create_track_number(generic_reader_c *reader,
 
   bool found   = false;
   int file_num = -1;
-  int i;
+  size_t i;
   for (i = 0; i < g_files.size(); i++)
     if (g_files[i].reader == reader) {
       found = true;
@@ -396,13 +352,12 @@ handle_segmentinfo() {
 
 static void
 list_file_types() {
-  mxinfo(Y("Known file types:\n"
-           "  ext   description\n"
-           "  ----  --------------------------\n"));
+  std::vector<file_type_t> &file_types = file_type_t::get_supported();
 
-  std::list<ext_file_type_t>::const_iterator i;
-  mxforeach(i, s_input_file_types)
-    mxinfo(boost::format("  %|1$-4s|  %2%\n") % i->ext % i->desc);
+  mxinfo(Y("Supported file types:\n"));
+
+  foreach(file_type_t &file_type, file_types)
+    mxinfo(boost::format("  %1% [%2%]\n") % file_type.title % file_type.extensions);
 }
 
 /** \brief Identify a file type and its contents
@@ -412,10 +367,15 @@ list_file_types() {
    and calls its identify function.
 */
 static void
-identify(const std::string &filename) {
+identify(std::string &filename) {
   track_info_c ti;
   filelist_t file;
 
+  if ('=' == filename[0]) {
+    ti.m_disable_multi_file = true;
+    filename                = filename.substr(1);
+  }
+
   verbose             = 0;
   g_suppress_warnings = true;
   g_identifying       = true;
@@ -545,7 +505,7 @@ parse_arg_tracks(std::string s,
   std::vector<std::string> elements = split(s, ",");
   strip(elements);
 
-  int i;
+  size_t i;
   for (i = 0; i < elements.size(); i++) {
     int64_t tid;
     if (!parse_int(elements[i], tid))
@@ -997,24 +957,43 @@ parse_arg_compression(const std::string &s,
   if (parts[1].size() == 0)
     mxerror(boost::format(Y("Invalid compression option specified in '--compression %1%'.\n")) % s);
 
+  std::vector<std::string> available_compression_methods;
+  available_compression_methods.push_back("none");
+  available_compression_methods.push_back("zlib");
+  available_compression_methods.push_back("mpeg4_p2");
+  available_compression_methods.push_back("analyze_header_removal");
+
   ti.m_compression_list[id] = COMPRESSION_UNSPECIFIED;
   parts[1] = downcase(parts[1]);
+
+  if (parts[1] == "zlib")
+    ti.m_compression_list[id] = COMPRESSION_ZLIB;
+
+  if (parts[1] == "none")
+    ti.m_compression_list[id] = COMPRESSION_NONE;
+
+  if ((parts[1] == "mpeg4_p2") || (parts[1] == "mpeg4p2"))
+    ti.m_compression_list[id] = COMPRESSION_MPEG4_P2;
+
+  if (parts[1] == "analyze_header_removal")
+      ti.m_compression_list[id] = COMPRESSION_ANALYZE_HEADER_REMOVAL;
+
 #ifdef HAVE_LZO
   if ((parts[1] == "lzo") || (parts[1] == "lzo1x"))
     ti.m_compression_list[id] = COMPRESSION_LZO;
+  else
+    available_compression_methods.push_back("lzo");
 #endif
-  if (parts[1] == "zlib")
-    ti.m_compression_list[id] = COMPRESSION_ZLIB;
+
 #ifdef HAVE_BZLIB_H
   if ((parts[1] == "bz2") || (parts[1] == "bzlib"))
     ti.m_compression_list[id] = COMPRESSION_BZ2;
+  else
+    available_compression_methods.push_back("bz2");
 #endif
-  if ((parts[1] == "mpeg4_p2") || (parts[1] == "mpeg4p2"))
-    ti.m_compression_list[id] = COMPRESSION_MPEG4_P2;
-  if (parts[1] == "none")
-    ti.m_compression_list[id] = COMPRESSION_NONE;
+
   if (ti.m_compression_list[id] == COMPRESSION_UNSPECIFIED)
-    mxerror(boost::format(Y("'%1%' is an unsupported argument for --compression. Available compression methods are 'none' and 'zlib'.\n")) % s);
+    mxerror(boost::format(Y("'%1%' is an unsupported argument for --compression. Available compression methods are: %2%\n")) % s % join(", ", available_compression_methods));
 }
 
 /** \brief Parse the argument for a couple of options
@@ -1141,7 +1120,7 @@ parse_arg_track_order(const std::string &s) {
   std::vector<std::string> parts = split(s, ",");
   strip(parts);
 
-  int i;
+  size_t i;
   for (i = 0; i < parts.size(); i++) {
     std::vector<std::string> pair = split(parts[i].c_str(), ":");
 
@@ -1507,7 +1486,7 @@ parse_arg_attachments(const std::string &param,
                       track_info_c &ti) {
   std::vector<std::string> elements = split(arg, ",");
 
-  int i;
+  size_t i;
   for (i = 0; elements.size() > i; ++i) {
     std::vector<std::string> pair = split(elements[i], ":");
 
@@ -2087,6 +2066,9 @@ parse_args(std::vector<std::string> args) {
     else if (this_arg == "+")
       append_next_file = true;
 
+    else if (this_arg == "=")
+      ti->m_disable_multi_file = true;
+
     // The argument is an input file.
     else {
       if (g_outfile == this_arg)
@@ -2109,6 +2091,11 @@ parse_args(std::vector<std::string> args) {
       if ('+' == this_arg[0]) {
         append_next_file = true;
         file.name        = this_arg.substr(1);
+
+      } else if ('=' == this_arg[0]) {
+        ti->m_disable_multi_file = true;
+        file.name                = this_arg.substr(1);
+
       } else
         file.name        = this_arg;
 
@@ -2187,7 +2174,6 @@ main(int argc,
      char **argv) {
   init_globals();
   setup();
-  init_input_file_type_list();
 
   parse_args(command_line_utf8(argc, argv));
 
