@@ -229,6 +229,10 @@ generic_packetizer_c::generic_packetizer_c(generic_reader_c *reader,
   else if (map_has_key(m_ti.m_nalu_size_lengths, -1))
     m_ti.m_nalu_size_length = m_ti.m_nalu_size_lengths[-1];
 
+  // Let's see if the user has specified a compression scheme for this track.
+  if (COMPRESSION_UNSPECIFIED != m_ti.m_compression)
+    m_hcompression = m_ti.m_compression;
+
   // Set default header values to 'unset'.
   if (!m_reader->m_appending)
     m_hserialno = create_track_number(m_reader, m_ti.m_id);
@@ -254,11 +258,11 @@ generic_packetizer_c::set_tag_track_uid() {
     return;
 
   convert_old_tags(*m_ti.m_tags);
-  int idx_tags;
+  size_t idx_tags;
   for (idx_tags = 0; m_ti.m_tags->ListSize() > idx_tags; ++idx_tags) {
     KaxTag *tag = (KaxTag *)(*m_ti.m_tags)[idx_tags];
 
-    int idx_tag;
+    size_t idx_tag;
     for (idx_tag = 0; tag->ListSize() > idx_tag; idx_tag++) {
       EbmlElement *el = (*tag)[idx_tag];
 
@@ -266,7 +270,7 @@ generic_packetizer_c::set_tag_track_uid() {
         continue;
 
       KaxTagTargets *targets = static_cast<KaxTagTargets *>(el);
-      int idx_target         = 0;
+      size_t idx_target      = 0;
 
       while (targets->ListSize() > idx_target) {
         EbmlElement *uid_el = (*targets)[idx_target];
@@ -583,7 +587,7 @@ generic_packetizer_c::set_headers() {
   }
 
   bool found = false;
-  int idx;
+  size_t idx;
   for (idx = 0; ptzrs_in_header_order.size() > idx; ++idx)
     if (this == ptzrs_in_header_order[idx]) {
       found = true;
@@ -721,8 +725,6 @@ generic_packetizer_c::set_headers() {
 
   }
 
-  if (COMPRESSION_UNSPECIFIED != m_ti.m_compression)
-    m_hcompression = m_ti.m_compression;
   if ((COMPRESSION_UNSPECIFIED != m_hcompression) && (COMPRESSION_NONE != m_hcompression)) {
     KaxContentEncoding &c_encoding = GetChild<KaxContentEncoding>(GetChild<KaxContentEncodings>(m_track_entry));
 
@@ -766,26 +768,25 @@ generic_packetizer_c::add_packet(packet_cptr pack) {
 
   // strip elements to be removed
   if (   (-1                     != m_htrack_max_add_block_ids)
-      && (pack->data_adds.size()  > m_htrack_max_add_block_ids))
+      && (pack->data_adds.size()  > static_cast<size_t>(m_htrack_max_add_block_ids)))
     pack->data_adds.resize(m_htrack_max_add_block_ids);
 
   if (m_compressor.is_set()) {
     try {
       m_compressor->compress(pack->data);
-      int i;
+      size_t i;
       for (i = 0; pack->data_adds.size() > i; ++i)
         m_compressor->compress(pack->data_adds[i]);
 
     } catch (compression_error_c &e) {
       mxerror_tid(m_ti.m_fname, m_ti.m_id, boost::format(Y("Compression failed: %1%\n")) % e.get_error());
     }
-
-  } else {
-    pack->data->grab();
-    int i;
-    for (i = 0; i < pack->data_adds.size(); i++)
-      pack->data_adds[i]->grab();
   }
+
+  pack->data->grab();
+  foreach(memory_cptr &data_add, pack->data_adds)
+    data_add->grab();
+
   pack->source = this;
 
   m_enqueued_bytes += pack->data->get_size();
@@ -807,18 +808,18 @@ generic_packetizer_c::add_packet(packet_cptr pack) {
 void
 generic_packetizer_c::add_packet2(packet_cptr pack) {
   pack->timecode   = ADJUST_TIMECODE(pack->timecode);
-  if (0 <= pack->bref)
+  if (pack->has_bref())
     pack->bref     = ADJUST_TIMECODE(pack->bref);
-  if (0 <= pack->fref)
+  if (pack->has_fref())
     pack->fref     = ADJUST_TIMECODE(pack->fref);
-  if (0 < pack->duration)
+  if (pack->has_duration())
     pack->duration = (int64_t)(pack->duration * m_ti.m_tcsync.numerator / m_ti.m_tcsync.denominator);
 
-  if ((2 > m_htrack_min_cache) && (0 <= pack->fref)) {
+  if ((2 > m_htrack_min_cache) && pack->has_fref()) {
     set_track_min_cache(2);
     rerender_track_headers();
 
-  } else if ((1 > m_htrack_min_cache) && (0 <= pack->bref)) {
+  } else if ((1 > m_htrack_min_cache) && pack->has_bref()) {
     set_track_min_cache(1);
     rerender_track_headers();
   }
@@ -834,9 +835,9 @@ generic_packetizer_c::add_packet2(packet_cptr pack) {
       int64_t needed_timecode_offset  = m_safety_last_timecode + m_safety_last_duration - pack->timecode;
       m_correction_timecode_offset   += needed_timecode_offset;
       pack->timecode                 += needed_timecode_offset;
-      if (0 <= pack->bref)
+      if (pack->has_bref())
         pack->bref += needed_timecode_offset;
-      if (0 <= pack->fref)
+      if (pack->has_fref())
         pack->fref += needed_timecode_offset;
 
       mxwarn_tid(m_ti.m_fname, m_ti.m_id,
@@ -983,8 +984,7 @@ generic_packetizer_c::apply_factory_full_queueing(packet_cptr_di &p_start) {
   while (m_packet_queue.end() != p_start) {
     // Find the next I frame packet.
     packet_cptr_di p_end = p_start + 1;
-    while ((m_packet_queue.end() != p_end) &&
-           ((0 <= (*p_end)->fref) || (0 <= (*p_end)->bref)))
+    while ((m_packet_queue.end() != p_end) && !(*p_end)->is_key_frame())
       ++p_end;
 
     // Abort if no such packet was found, but keep on assigning if the
@@ -997,7 +997,7 @@ generic_packetizer_c::apply_factory_full_queueing(packet_cptr_di &p_start) {
     std::vector<packet_sorter_t> sorter;
     bool needs_sorting        = false;
     int64_t previous_timecode = 0;
-    int i                     = distance(m_packet_queue.begin(), p_start);
+    size_t i                  = distance(m_packet_queue.begin(), p_start);
 
     packet_cptr_di p_current;
     for (p_current = p_start; p_current != p_end; ++i, ++p_current) {
@@ -1043,8 +1043,8 @@ generic_packetizer_c::handle_avi_audio_sync(int64_t num_bytes,
      duration = num_bytes * 1000000000 / m_ti.m_avi_avg_bytes_per_sec;
 
   else {
-    int num_blocks = 0;
-    int i;
+    unsigned int num_blocks = 0;
+    size_t i;
     for (i = 0; (m_ti.m_avi_block_sizes.size() > i) && (0 < num_bytes); ++i) {
       int64_t block_size  = m_ti.m_avi_block_sizes[i];
       num_blocks         += (block_size + m_ti.m_avi_block_align - 1) / m_ti.m_avi_block_align;
@@ -1119,7 +1119,7 @@ generic_packetizer_c::is_compatible_with(output_compatibility_e compatibility) {
     add_requested_track_id(i->first);
 
 #define add_all_requested_track_ids2(container) \
-  for (int i = 0; i < m_ti.container.size(); i++) \
+  for (size_t i = 0; i < m_ti.container.size(); i++) \
     add_requested_track_id(m_ti.container[i]);
 
 generic_reader_c::generic_reader_c(track_info_c &ti)
@@ -1155,7 +1155,7 @@ generic_reader_c::generic_reader_c(track_info_c &ti)
 }
 
 generic_reader_c::~generic_reader_c() {
-  int i;
+  size_t i;
 
   for (i = 0; i < m_reader_packetizers.size(); i++)
     delete m_reader_packetizers[i];
@@ -1165,7 +1165,7 @@ generic_reader_c::~generic_reader_c() {
 
 void
 generic_reader_c::read_all() {
-  int i;
+  size_t i;
 
   for (i = 0; m_reader_packetizers.size() > i; ++i) {
     while (read(m_reader_packetizers[i], true) != 0)
@@ -1209,7 +1209,7 @@ generic_reader_c::demuxing_requested(char type,
   if (tracks->empty())
     return true;
 
-  int i;
+  size_t i;
   for (i = 0; i < tracks->size(); i++)
     if ((*tracks)[i] == id)
       return true;
@@ -1247,6 +1247,13 @@ generic_reader_c::add_packetizer(generic_packetizer_c *ptzr) {
   return m_reader_packetizers.size() - 1;
 }
 
+size_t
+generic_reader_c::get_num_packetizers()
+  const
+{
+  return m_reader_packetizers.size();
+}
+
 void
 generic_reader_c::set_timecode_offset(int64_t offset) {
   m_max_timecode_seen = offset;
@@ -1274,10 +1281,10 @@ void
 generic_reader_c::check_track_ids_and_packetizers() {
   add_available_track_ids();
 
-  int r;
+  size_t r;
   for (r = 0; m_requested_track_ids.size() > r; ++r) {
     bool found = false;
-    int a;
+    size_t a;
     for (a = 0; m_available_track_ids.size() > a; ++a)
       if (m_requested_track_ids[r] == m_available_track_ids[a]) {
         found = true;
@@ -1297,7 +1304,7 @@ generic_reader_c::add_requested_track_id(int64_t id) {
     return;
 
   bool found = false;
-  int i;
+  size_t i;
   for (i = 0; i < m_requested_track_ids.size(); i++)
     if (m_requested_track_ids[i] == id) {
       found = true;
@@ -1318,12 +1325,24 @@ generic_reader_c::get_queued_bytes() {
   return bytes;
 }
 
-void
-generic_reader_c::flush_packetizers() {
-  std::vector<generic_packetizer_c *>::const_iterator it;
+file_status_e
+generic_reader_c::flush_packetizer(int num) {
+  return flush_packetizer(PTZR(num));
+}
 
-  mxforeach(it, m_reader_packetizers)
-    (*it)->flush();
+file_status_e
+generic_reader_c::flush_packetizer(generic_packetizer_c *ptzr) {
+  ptzr->flush();
+
+  return FILE_STATUS_DONE;
+}
+
+file_status_e
+generic_reader_c::flush_packetizers() {
+  foreach(generic_packetizer_c *ptzr, m_reader_packetizers)
+    ptzr->flush();
+
+  return FILE_STATUS_DONE;
 }
 
 void
@@ -1494,6 +1513,7 @@ track_info_c::track_info_c()
   , m_no_subs(false)
   , m_no_buttons(false)
   , m_no_track_tags(false)
+  , m_disable_multi_file(false)
   , m_private_data(NULL)
   , m_private_size(0)
   , m_aspect_ratio(0.0)
@@ -1553,6 +1573,7 @@ track_info_c::operator =(const track_info_c &src) {
   m_stracks                    = src.m_stracks;
   m_vtracks                    = src.m_vtracks;
   m_track_tags                 = src.m_track_tags;
+  m_disable_multi_file         = src.m_disable_multi_file;
 
   m_private_size               = src.m_private_size;
   m_private_data               = (unsigned char *)safememdup(src.m_private_data, m_private_size);
