@@ -193,10 +193,11 @@ public:
   std::string m_fname;
   bool m_no_audio, m_no_video, m_no_subs, m_no_buttons, m_no_track_tags;
   std::vector<int64_t> m_atracks, m_vtracks, m_stracks, m_btracks, m_track_tags;
+  bool m_disable_multi_file;
 
   // Options used by the packetizers.
   unsigned char *m_private_data;
-  int m_private_size;
+  size_t m_private_size;
 
   std::map<int64_t, std::string> m_all_fourccs;
   std::string m_fourcc;
@@ -324,6 +325,7 @@ public:
   }
 
   virtual int add_packetizer(generic_packetizer_c *ptzr);
+  virtual size_t get_num_packetizers() const;
   virtual void set_timecode_offset(int64_t offset);
 
   virtual void check_track_ids_and_packetizers();
@@ -333,7 +335,9 @@ public:
 
   virtual int64_t get_queued_bytes();
 
-  virtual void flush_packetizers();
+  virtual file_status_e flush_packetizer(int num);
+  virtual file_status_e flush_packetizer(generic_packetizer_c *ptzr);
+  virtual file_status_e flush_packetizers();
 
   virtual attach_mode_e attachment_requested(int64_t id);
 
@@ -427,7 +431,7 @@ protected:
 
   std::string m_hcodec_id;
   unsigned char *m_hcodec_private;
-  int m_hcodec_private_length;
+  size_t m_hcodec_private_length;
 
   float m_haudio_sampling_freq, m_haudio_output_sampling_freq;
   int m_haudio_channels, m_haudio_bit_depth;
@@ -564,7 +568,8 @@ public:
   virtual void set_track_name(const std::string &name);
 
   virtual void set_default_compression_method(compression_method_e method) {
-    m_hcompression = method;
+    if (COMPRESSION_UNSPECIFIED == m_hcompression)
+      m_hcompression = method;
   }
 
   virtual void force_duration_on_last_packet();
