@@ -44,7 +44,6 @@
 #include "mmg/cli_options_dlg.h"
 #include "mmg/header_editor/frame.h"
 #include "mmg/jobs.h"
-#include "mmg/matroskalogo.xpm"
 #include "mmg/mmg_dialog.h"
 #include "mmg/mmg.h"
 #include "mmg/mux_dialog.h"
@@ -54,6 +53,7 @@
 #include "mmg/tabs/chapters.h"
 #include "mmg/tabs/global.h"
 #include "mmg/tabs/input.h"
+#include "share/icons/32x32/mkvmergeGUI.xpm"
 
 mmg_dialog *mdlg;
 wxString last_open_dir;
@@ -158,7 +158,7 @@ mmg_dialog::mmg_dialog()
 
   load_job_queue();
 
-  SetIcon(wxIcon(matroskalogo_xpm));
+  SetIcon(wxIcon(mkvmergeGUI_xpm));
 
   help = NULL;
 
@@ -502,7 +502,7 @@ mmg_dialog::check_before_overwriting() {
   wxFileName file_name(tc_output->GetValue());
   wxString dir, name, ext;
   wxArrayString files_in_output_dir;
-  int i;
+  size_t i;
 
   dir = file_name.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
 
@@ -543,7 +543,7 @@ mmg_dialog::is_output_file_name_valid() {
   wxFileName output_file_name(tc_output->GetValue());
   wxString check_name(output_file_name.GetFullName());
 
-  int i;
+  size_t i;
   for (i = 0; check_name.Length() > i; ++i)
     if (wxNOT_FOUND != forbidden_chars.Find(check_name[i]))
       return false;
@@ -986,9 +986,9 @@ mmg_dialog::update_command_line() {
         clargs.Add(wxString::Format(wxT("%s:%d"), sid.c_str(), t->stereo_mode - 1));
       }
 
-      if (!t->appending && (t->compression.Length() > 0)) {
+      if (!t->appending && !t->compression.IsEmpty()) {
         wxString compression = t->compression;
-        if (compression == wxT("none"))
+        if (compression == Z("none"))
           compression = wxT("none");
         clargs.Add(wxT("--compression"));
         clargs.Add(sid + wxT(":") + compression);
@@ -1182,7 +1182,7 @@ mmg_dialog::update_command_line() {
 
 void
 mmg_dialog::on_file_load_last(wxCommandEvent &evt) {
-  if ((evt.GetId() < ID_M_FILE_LOADLAST1) || ((evt.GetId() - ID_M_FILE_LOADLAST1) >= last_settings.size()))
+  if ((evt.GetId() < ID_M_FILE_LOADLAST1) || (static_cast<size_t>(evt.GetId() - ID_M_FILE_LOADLAST1) >= last_settings.size()))
     return;
 
   load(last_settings[evt.GetId() - ID_M_FILE_LOADLAST1]);
@@ -1190,7 +1190,7 @@ mmg_dialog::on_file_load_last(wxCommandEvent &evt) {
 
 void
 mmg_dialog::on_chapters_load_last(wxCommandEvent &evt) {
-  if ((evt.GetId() < ID_M_CHAPTERS_LOADLAST1) || ((evt.GetId() - ID_M_CHAPTERS_LOADLAST1) >= last_chapters.size()))
+  if ((evt.GetId() < ID_M_CHAPTERS_LOADLAST1) || (static_cast<size_t>(evt.GetId() - ID_M_CHAPTERS_LOADLAST1) >= last_chapters.size()))
     return;
 
   notebook->SetSelection(4);
@@ -1351,7 +1351,8 @@ void
 mmg_dialog::on_add_to_jobqueue(wxCommandEvent &evt) {
   wxString description, line;
   job_t job;
-  int i, result;
+  size_t i;
+  int result;
   bool ok;
 
   if (!input_page->validate_settings() ||
@@ -1427,7 +1428,8 @@ mmg_dialog::on_manage_jobs(wxCommandEvent &evt) {
 
 void
 mmg_dialog::load_job_queue() {
-  int num, i, value;
+  size_t i;
+  int num, value;
   wxString s;
   wxConfigBase *cfg;
   job_t job;
@@ -1446,7 +1448,7 @@ mmg_dialog::load_job_queue() {
   }
   jobs.clear();
 
-  for (i = 0; i < num; i++) {
+  for (i = 0; i < static_cast<size_t>(num); i++) {
     cfg->SetPath(wxT("/jobs"));
     s.Printf(wxT("%u"), i);
     if (!cfg->HasGroup(s))
@@ -1541,6 +1543,7 @@ mmg_dialog::save_preferences() {
   cfg->Write(wxU("warn_usage"),                      options.warn_usage);
   cfg->Write(wxU("gui_debugging"),                   options.gui_debugging);
   cfg->Write(wxU("set_delay_from_filename"),         options.set_delay_from_filename);
+  cfg->Write(wxU("disable_a_v_compression"),         options.disable_a_v_compression);
   cfg->Write(wxU("popular_languages"),               join(wxU(" "), options.popular_languages));
 
   cfg->Flush();
@@ -1575,6 +1578,7 @@ mmg_dialog::load_preferences() {
   cfg->Read(wxU("warn_usage"),                    &options.warn_usage, true);
   cfg->Read(wxU("gui_debugging"),                 &options.gui_debugging, false);
   cfg->Read(wxU("set_delay_from_filename"),       &options.set_delay_from_filename, true);
+  cfg->Read(wxU("disable_a_v_compression"),       &options.disable_a_v_compression, false);
   cfg->Read(wxU("popular_languages"),             &s, wxEmptyString);
 
   options.init_popular_languages(s);
@@ -1663,8 +1667,17 @@ mmg_dialog::on_file_options(wxCommandEvent &evt) {
 
 void
 mmg_dialog::on_run_header_editor(wxCommandEvent &evt) {
-  header_editor_frames.push_back(new header_editor_frame_c(this));
-  header_editor_frames.back()->Show();
+  create_header_editor_window();
+}
+
+void
+mmg_dialog::create_header_editor_window(const wxString &file_name) {
+  header_editor_frame_c *frame = new header_editor_frame_c(this);
+  header_editor_frames.push_back(frame);
+  frame->Show();
+
+  if (!file_name.IsEmpty())
+    frame->open_file(wxFileName(file_name));
 }
 
 void
@@ -1677,7 +1690,8 @@ mmg_dialog::query_mkvmerge_capabilities() {
   wxString tmp;
   wxArrayString output;
   std::vector<wxString> parts;
-  int result, i;
+  size_t i;
+  int result;
 
   wxLogMessage(Z("Querying mkvmerge's capabilities"));
   tmp = wxT("\"") + options.mkvmerge + wxT("\" --capabilities");
