@@ -29,6 +29,7 @@
 #include "common/error.h"
 #include "common/extern_data.h"
 #include "common/iso639.h"
+#include "common/mm_write_cache_io.h"
 #include "common/strings/editing.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
@@ -330,7 +331,7 @@ tab_chapters::translate_ui() {
   b_set_values->SetToolTip(TIP("Here you can set the values for the language and the country that you want to apply to all the "
                                "chapters below and including the currently selected entry."));
   b_adjust_timecodes->SetLabel(Z("Adjust timecodes"));
-  b_adjust_timecodes->SetToolTip(TIP("Here you can adjust all the timcdoes of the selected chapter and all its childrend by a specific amount either increasing or decreasing it."));
+  b_adjust_timecodes->SetToolTip(TIP("Here you can adjust all the timecodes of the selected chapter and of all its sub-chapters by a specific amount either increasing or decreasing them."));
   st_start->SetLabel(Z("Start:"));
   st_end->SetLabel(Z("End:"));
   st_uid->SetLabel(Z("UID:"));
@@ -566,6 +567,8 @@ tab_chapters::load(wxString name) {
       source_is_kax_file = true;
       source_is_simple_format = false;
 
+      analyzer->close_file();
+
     } else {
       new_chapters = parse_chapters(wxMB(name), 0, -1, 0, "", "", true,
                                     &source_is_simple_format);
@@ -658,6 +661,8 @@ tab_chapters::on_save_chapters_to_kax_file(wxCommandEvent &evt) {
 
   write_chapters_to_matroska_file();
   mdlg->set_last_chapters_in_menu(file_name);
+
+  analyzer->close_file();
 }
 
 void
@@ -694,7 +699,7 @@ tab_chapters::save() {
   wxString err;
 
   try {
-    out = new mm_file_io_c(wxMB(file_name), MODE_CREATE);
+    out = mm_write_cache_io_c::open(wxMB(file_name), 128 * 1024);
   } catch (...) {
     err.Printf(Z("Could not open the destination file '%s' for writing. Error code: %d (%s)."), file_name.c_str(), errno, wxUCS(strerror(errno)));
     wxMessageBox(err, Z("Error opening file"), wxCENTER | wxOK | wxICON_ERROR);
@@ -1110,7 +1115,7 @@ tab_chapters::on_language_code_selected(wxCommandEvent &evt) {
   KaxChapterDisplay *cdisplay;
   KaxChapterLanguage *clanguage;
   chapter_node_data_c *t;
-  uint32_t i, n;
+  size_t i, n;
   wxString label;
   wxTreeItemId id;
 
@@ -1126,7 +1131,7 @@ tab_chapters::on_language_code_selected(wxCommandEvent &evt) {
   for (i = 0; i < t->chapter->ListSize(); i++)
     if (EbmlId(*(*t->chapter)[i]) == KaxChapterDisplay::ClassInfos.GlobalId) {
       n++;
-      if (n == (lb_chapter_names->GetSelection() + 1)) {
+      if (n == static_cast<size_t>(lb_chapter_names->GetSelection() + 1)) {
         cdisplay = (KaxChapterDisplay *)(*t->chapter)[i];
         break;
       }
@@ -1147,7 +1152,7 @@ tab_chapters::on_country_code_selected(wxCommandEvent &evt) {
   KaxChapterDisplay *cdisplay;
   KaxChapterCountry *ccountry;
   chapter_node_data_c *t;
-  uint32_t i, n;
+  size_t i, n;
   wxTreeItemId id;
 
   id = tc_chapters->GetSelection();
@@ -1162,7 +1167,7 @@ tab_chapters::on_country_code_selected(wxCommandEvent &evt) {
   for (i = 0; i < t->chapter->ListSize(); i++)
     if (EbmlId(*(*t->chapter)[i]) == KaxChapterDisplay::ClassInfos.GlobalId) {
       n++;
-      if (n == (lb_chapter_names->GetSelection() + 1)) {
+      if (n == static_cast<size_t>(lb_chapter_names->GetSelection() + 1)) {
         cdisplay = (KaxChapterDisplay *)(*t->chapter)[i];
         break;
       }
@@ -1190,7 +1195,7 @@ void
 tab_chapters::on_chapter_name_changed(wxCommandEvent &evt) {
   KaxChapterDisplay *cdisplay;
   chapter_node_data_c *t;
-  uint32_t i, n;
+  size_t i, n;
   wxString label;
   wxTreeItemId id;
 
@@ -1209,7 +1214,7 @@ tab_chapters::on_chapter_name_changed(wxCommandEvent &evt) {
   for (i = 0; i < t->chapter->ListSize(); i++)
     if (EbmlId(*(*t->chapter)[i]) == KaxChapterDisplay::ClassInfos.GlobalId) {
       n++;
-      if (n == (lb_chapter_names->GetSelection() + 1)) {
+      if (n == static_cast<size_t>(lb_chapter_names->GetSelection() + 1)) {
         cdisplay = (KaxChapterDisplay *)(*t->chapter)[i];
         break;
       }
@@ -1286,7 +1291,7 @@ tab_chapters::on_set_values(wxCommandEvent &evt) {
   wxTreeItemId id;
   chapter_node_data_c *t;
   wxString s;
-  uint32_t i, n;
+  size_t i, n;
   chapter_values_dlg dlg(this);
 
   id = tc_chapters->GetSelection();
@@ -1318,7 +1323,7 @@ tab_chapters::on_set_values(wxCommandEvent &evt) {
   for (i = 0; i < t->chapter->ListSize(); i++)
     if (EbmlId(*(*t->chapter)[i]) == KaxChapterDisplay::ClassInfos.GlobalId) {
       n++;
-      if (n == (lb_chapter_names->GetSelection() + 1)) {
+      if (n == static_cast<size_t>(lb_chapter_names->GetSelection() + 1)) {
         cdisplay = (KaxChapterDisplay *)(*t->chapter)[i];
         break;
       }
@@ -1335,7 +1340,7 @@ tab_chapters::on_adjust_timecodes(wxCommandEvent &evt) {
   wxTreeItemId id;
   chapter_node_data_c *t;
   wxString sadjustment;
-  uint32_t i, n, offset;
+  size_t i, n, offset;
   int64_t adjustment, mult;
 
   id = tc_chapters->GetSelection();
@@ -1389,7 +1394,7 @@ tab_chapters::on_adjust_timecodes(wxCommandEvent &evt) {
   for (i = 0; i < t->chapter->ListSize(); i++)
     if (EbmlId(*(*t->chapter)[i]) == KaxChapterDisplay::ClassInfos.GlobalId) {
       n++;
-      if (n == (lb_chapter_names->GetSelection() + 1)) {
+      if (n == static_cast<size_t>(lb_chapter_names->GetSelection() + 1)) {
         cdisplay = (KaxChapterDisplay *)(*t->chapter)[i];
         break;
       }
@@ -1542,7 +1547,7 @@ void
 tab_chapters::on_add_chapter_name(wxCommandEvent &evt) {
   KaxChapterDisplay *cdisplay;
   chapter_node_data_c *t;
-  uint32_t i, n;
+  size_t i, n;
   wxTreeItemId id;
   wxString s;
 
@@ -1558,7 +1563,7 @@ tab_chapters::on_add_chapter_name(wxCommandEvent &evt) {
   for (i = 0; i < t->chapter->ListSize(); i++)
     if (EbmlId(*(*t->chapter)[i]) == KaxChapterDisplay::ClassInfos.GlobalId) {
       n++;
-      if (n == (lb_chapter_names->GetSelection() + 1)) {
+      if (n == static_cast<size_t>(lb_chapter_names->GetSelection() + 1)) {
         cdisplay = (KaxChapterDisplay *)(*t->chapter)[i];
         break;
       }
@@ -1593,7 +1598,7 @@ void
 tab_chapters::on_remove_chapter_name(wxCommandEvent &evt) {
   KaxChapterDisplay *cdisplay;
   chapter_node_data_c *t;
-  uint32_t i, n;
+  size_t i, n;
   wxTreeItemId id;
   wxString s;
 
@@ -1609,7 +1614,7 @@ tab_chapters::on_remove_chapter_name(wxCommandEvent &evt) {
   for (i = 0; i < t->chapter->ListSize(); i++)
     if (EbmlId(*(*t->chapter)[i]) == KaxChapterDisplay::ClassInfos.GlobalId) {
       n++;
-      if (n == (lb_chapter_names->GetSelection() + 1)) {
+      if (n == static_cast<size_t>(lb_chapter_names->GetSelection() + 1)) {
         cdisplay = (KaxChapterDisplay *)(*t->chapter)[i];
         break;
       }
@@ -1634,7 +1639,7 @@ tab_chapters::on_remove_chapter_name(wxCommandEvent &evt) {
   for (i = 0; i < t->chapter->ListSize(); i++)
     if (EbmlId(*(*t->chapter)[i]) == KaxChapterDisplay::ClassInfos.GlobalId) {
       n++;
-      if (n == (lb_chapter_names->GetSelection() + 1)) {
+      if (n == static_cast<size_t>(lb_chapter_names->GetSelection() + 1)) {
         cdisplay = (KaxChapterDisplay *)(*t->chapter)[i];
         break;
       }
@@ -1650,7 +1655,7 @@ void
 tab_chapters::on_chapter_name_selected(wxCommandEvent &evt) {
   KaxChapterDisplay *cdisplay;
   chapter_node_data_c *t;
-  uint32_t i, n;
+  size_t i, n;
   wxTreeItemId id;
   wxString s;
 
@@ -1665,7 +1670,7 @@ tab_chapters::on_chapter_name_selected(wxCommandEvent &evt) {
   for (i = 0; i < t->chapter->ListSize(); i++)
     if (EbmlId(*(*t->chapter)[i]) == KaxChapterDisplay::ClassInfos.GlobalId) {
       n++;
-      if (n == (lb_chapter_names->GetSelection() + 1)) {
+      if (n == static_cast<size_t>(lb_chapter_names->GetSelection() + 1)) {
         cdisplay = (KaxChapterDisplay *)(*t->chapter)[i];
         break;
       }
@@ -1718,7 +1723,7 @@ void
 tab_chapters::on_flag_hidden(wxCommandEvent &evt) {
   wxTreeItemId selected;
   chapter_node_data_c *t;
-  int i;
+  size_t i;
 
   selected = tc_chapters->GetSelection();
   if (!selected.IsOk() || (selected == tid_root))
@@ -1742,7 +1747,7 @@ void
 tab_chapters::on_flag_enabled(wxCommandEvent &evt) {
   wxTreeItemId selected;
   chapter_node_data_c *t;
-  int i;
+  size_t i;
 
   selected = tc_chapters->GetSelection();
   if (!selected.IsOk() || (selected == tid_root))
