@@ -74,7 +74,7 @@ public:
   input_drop_target_c(tab_input *n_owner):
     owner(n_owner) {}
   virtual bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString &dropped_files) {
-    int i;
+    size_t i;
 
     for (i = 0; i < dropped_files.Count(); i++)
       owner->add_file(dropped_files[i], false);
@@ -213,56 +213,18 @@ tab_input::set_track_mode(mmg_track_t *t) {
   ti_extra->set_track_mode(t);
 }
 
-struct file_type_t {
-  wxString title, extensions;
-
-  file_type_t(const wxString &n_title, const wxString &n_extensions)
-    : title(n_title)
-    , extensions(n_extensions) {
-  }
-};
-
 wxString
 tab_input::setup_file_type_filter() {
   if (!media_files.empty())
     return media_files;
 
-  std::vector<file_type_t> file_types;
-
-  file_types.push_back(file_type_t(Z("A/52 (aka AC3)"),                      wxU("ac3")));
-  file_types.push_back(file_type_t(Z("AAC (Advanced Audio Coding)"),         wxU("aac m4a mp4")));
-  file_types.push_back(file_type_t(Z("AVC/h.264 elementary streams"),        wxU("264 avc h264 x264")));
-  file_types.push_back(file_type_t(Z("AVI (Audio/Video Interleaved)"),       wxU("avi")));
-  file_types.push_back(file_type_t(Z("Dirac"),                               wxU("drc")));
-  file_types.push_back(file_type_t(Z("Dolby TrueHD"),                        wxU("thd thd+ac3 truehd true-hd")));
-  file_types.push_back(file_type_t(Z("DTS/DTS-HD (Digital Theater System)"), wxU("dts dtshd dts-hd")));
-  if (capabilities[wxT("FLAC")] == wxT("true"))
-    file_types.push_back(file_type_t(Z("FLAC (Free Lossless Audio Codec)"),  wxU("flac ogg")));
-  file_types.push_back(file_type_t(Z("IVF with VP8 video files"),            wxU("ivf")));
-  file_types.push_back(file_type_t(Z("MP4 audio/video files"),               wxU("mp4")));
-  file_types.push_back(file_type_t(Z("MPEG audio files"),                    wxU("mp2 mp3")));
-  file_types.push_back(file_type_t(Z("MPEG program streams"),                wxU("mpg mpeg m2v evo evob vob")));
-  file_types.push_back(file_type_t(Z("MPEG video elementary streams"),       wxU("m1v m2v")));
-  file_types.push_back(file_type_t(Z("Matroska audio/video files"),          wxU("mka mks mkv webm webmv webma")));
-  file_types.push_back(file_type_t(Z("QuickTime audio/video files"),         wxU("mov")));
-  file_types.push_back(file_type_t(Z("Ogg/OGM audio/video files"),           wxU("ogg ogm")));
-  file_types.push_back(file_type_t(Z("RealMedia audio/video files"),         wxU("ra ram rm rmvb rv")));
-  file_types.push_back(file_type_t(Z("SRT text subtitles"),                  wxU("srt")));
-  file_types.push_back(file_type_t(Z("SSA/ASS text subtitles"),              wxU("ass ssa")));
-  file_types.push_back(file_type_t(Z("TTA (The lossless True Audio codec)"), wxU("tta")));
-  file_types.push_back(file_type_t(Z("USF text subtitles"),                  wxU("usf xml")));
-  file_types.push_back(file_type_t(Z("VC1 elementary streams"),              wxU("vc1")));
-  file_types.push_back(file_type_t(Z("VobButtons"),                          wxU("btn")));
-  file_types.push_back(file_type_t(Z("VobSub subtitles"),                    wxU("idx")));
-  file_types.push_back(file_type_t(Z("WAVE (uncompressed PCM audio)"),       wxU("wav")));
-  file_types.push_back(file_type_t(Z("WAVPACK v4 audio"),                    wxU("wv")));
-  file_types.push_back(file_type_t(Z("WebM audio/video files"),              wxU("webm webmv webma")));
+  std::vector<file_type_t> &file_types = file_type_t::get_supported();
 
   std::map<wxString, bool> all_extensions_map;
   wxString filters;
 
   foreach(file_type_t &file_type, file_types) {
-    std::vector<wxString> extensions = split(wxString(file_type.extensions), wxU(" "));
+    std::vector<wxString> extensions = split(wxU(file_type.extensions), wxU(" "));
     std::vector<wxString> extensions_full;
 
     foreach(wxString &extension, extensions) {
@@ -278,7 +240,7 @@ tab_input::setup_file_type_filter() {
     }
 
     wxString filter_ext  = join(wxT(";"), extensions_full);
-    filters             += wxString::Format(wxT("|%s (%s)|%s"), file_type.title.c_str(), filter_ext.c_str(), filter_ext.c_str());
+    filters             += wxString::Format(wxT("|%s (%s)|%s"), wxU(file_type.title).c_str(), filter_ext.c_str(), filter_ext.c_str());
   }
 
   std::vector<wxString> all_extensions;
@@ -299,7 +261,7 @@ tab_input::select_file(bool append) {
     return;
 
   wxArrayString selected_files;
-  int i;
+  size_t i;
 
   dlg.GetPaths(selected_files);
   for (i = 0; i < selected_files.Count(); i++)
@@ -322,7 +284,7 @@ tab_input::add_file(const wxString &file_name,
   wxString name, command, video_track_name, opt_file_name;
   wxArrayString output, errors;
   std::vector<wxString> args, pair;
-  int result, pos, new_file_pos;
+  int new_file_pos, result;
   unsigned int i, k;
   wxFile *opt_file;
   std::string arg_utf8;
@@ -376,7 +338,8 @@ tab_input::add_file(const wxString &file_name,
   if (3 == result) {
     wxString container = Z("unknown");
 
-    if (output.Count() && (0 <= (pos = output[0].Find(wxT("container:")))))
+    int pos;
+    if (output.Count() && (wxNOT_FOUND != (pos = output[0].Find(wxT("container:")))))
       container = output[0].Mid(pos + 11);
 
     wxString info;
@@ -431,6 +394,8 @@ tab_input::add_file(const wxString &file_name,
   default_track_found_for['s'] = -1 != default_track_checked('s');
 
   for (i = 0; i < output.Count(); i++) {
+    int pos;
+
     if (output[i].Find(wxT("Track")) == 0) {
       mmg_track_cptr track(new mmg_track_t);
 
@@ -533,7 +498,12 @@ tab_input::add_file(const wxString &file_name,
         cfg->Flush();
       }
 
-    } else if ((pos = output[i].Find(wxT("container:"))) > 0) {
+      if (   mdlg->options.disable_a_v_compression
+          && !track->appending
+          && (('v' == track->type) || ('a' == track->type)))
+        track->compression = wxU("none");
+
+    } else if ((pos = output[i].Find(wxT("container:"))) != wxNOT_FOUND) {
       wxString container = output[i].Mid(pos + 11).BeforeFirst(wxT(' '));
       wxString info      = output[i].Mid(pos + 11).AfterFirst(wxT('[')).BeforeLast(wxT(']'));
 
@@ -658,7 +628,7 @@ tab_input::add_file(const wxString &file_name,
     else {
       do {
         ++new_file_pos;
-      } while ((files.size() > new_file_pos) && files[new_file_pos]->appending);
+      } while ((files.size() > static_cast<size_t>(new_file_pos)) && files[new_file_pos]->appending);
     }
   }
 
@@ -697,9 +667,9 @@ tab_input::add_file(const wxString &file_name,
     // Then I have to skip over all the other tracks that are already appended
     // to that n'th track. The insertion point is right after that.
     if (append) {
-      int nth_old_track = 0;
-      new_track_pos     = 0;
-      while ((tracks.size() > new_track_pos) && (nth_old_track < (i + 1))) {
+      unsigned int nth_old_track = 0;
+      new_track_pos              = 0;
+      while ((tracks.size() > static_cast<size_t>(new_track_pos)) && (nth_old_track < (i + 1))) {
         if (tracks[new_track_pos]->source == (new_file_pos - 1))
           ++nth_old_track;
         ++new_track_pos;
@@ -710,7 +680,7 @@ tab_input::add_file(const wxString &file_name,
       // at the end and let the user figure out which track he really wants
       // to append it to.
       if (nth_old_track == (i + 1))
-        while ((tracks.size() > new_track_pos) && tracks[new_track_pos]->appending)
+        while ((tracks.size() > static_cast<size_t>(new_track_pos)) && tracks[new_track_pos]->appending)
           ++new_track_pos;
 
     } else
@@ -873,7 +843,7 @@ tab_input::on_move_track_up(wxCommandEvent &evt) {
 
 void
 tab_input::on_move_track_down(wxCommandEvent &evt) {
-  if ((0 > selected_track) || (selected_track >= tracks.size() - 1))
+  if ((0 > selected_track) || (static_cast<size_t>(selected_track) >= tracks.size() - 1))
     return;
 
   // Appended tracks may not be at the top.
@@ -897,7 +867,7 @@ tab_input::on_move_track_down(wxCommandEvent &evt) {
   current_track++;
 
   b_track_up->Enable(true);
-  b_track_down->Enable(current_track < (tracks.size() - 1));
+  b_track_down->Enable(current_track < static_cast<int>(tracks.size() - 1));
 
   selected_track       = current_track;
   dont_copy_values_now = false;
@@ -929,7 +899,7 @@ tab_input::on_track_selected(wxCommandEvent &evt) {
   mmg_track_t *t = tracks[new_sel];
 
   b_track_up->Enable(new_sel > 0);
-  b_track_down->Enable(new_sel < (tracks.size() - 1));
+  b_track_down->Enable(new_sel < static_cast<int>(tracks.size() - 1));
 
   set_track_mode(t);
 
@@ -1246,7 +1216,7 @@ tab_input::load(wxConfigBase *cfg,
   strip(s);
   if (s.length() > 0) {
     std::vector<wxString> entries = split(s, (wxString)wxT(","));
-    int i;
+    size_t i;
     for (i = 0; i < entries.size(); i++) {
       std::vector<wxString> pair = split(entries[i], (wxString)wxT(":"));
       if (pair.size() != 2)
@@ -1256,14 +1226,14 @@ tab_input::load(wxConfigBase *cfg,
                 "Moritz Bunkus <moritz@bunkus.org>\n\n"
                 "(Problem occured in tab_input::load(), #1)"));
       long tidx;
-      if (!pair[0].ToLong(&fidx) || !pair[1].ToLong(&tidx) || (fidx >= files.size()))
+      if (!pair[0].ToLong(&fidx) || !pair[1].ToLong(&tidx) || (fidx >= static_cast<long>(files.size())))
         wxdie(Z("The job file could not have been parsed correctly.\n"
                 "Either it is invalid / damaged, or you've just found\n"
                 "a bug in mmg. Please report this to the author\n"
                 "Moritz Bunkus <moritz@bunkus.org>\n\n"
                 "(Problem occured in tab_input::load(), #2)"));
       bool found = false;
-      int j;
+      size_t j;
       for (j = 0; j < files[fidx]->tracks.size(); j++)
         if (files[fidx]->tracks[j]->id == tidx) {
           found = true;
@@ -1383,7 +1353,7 @@ tab_input::validate_settings() {
       strip(s);
       if (s.length() > 0) {
         bool dot_present = false;
-        int i            = 0;
+        size_t i         = 0;
         bool ok          = true;
         while (i < s.length()) {
           if (isdigit(s[i]) || (!dot_present && ((s[i] == '.') || (s[i] == ',')))) {
